@@ -1,6 +1,6 @@
 /* A sort of clone of the cddlib test program `lcdd'.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2016 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -21,7 +21,9 @@ Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 For the most up-to-date information see the Parma Polyhedra Library
 site: http://bugseng.com/products/ppl/ . */
 
-//#define USE_PIPLIB 1
+#if 0
+#define USE_PIPLIB 1
+#endif
 
 #if (!defined(USE_PPL) && !defined(USE_PIPLIB))
 #define USE_PPL 1
@@ -41,12 +43,6 @@ namespace PPL = Parma_Polyhedra_Library;
 
 typedef PPL::C_Polyhedron POLYHEDRON_TYPE;
 
-#if !PPL_CXX_SUPPORTS_ATTRIBUTE_WEAK
-extern "C" void
-ppl_set_GMP_memory_allocation_functions(void) {
-}
-#endif
-
 #elif defined(USE_PIPLIB)
 
 #error "PipLib not supported yet"
@@ -122,53 +118,55 @@ pip_display_sol(std::ostream& out,
                 const Parma_Polyhedra_Library::Variables_Set& vars,
                 Parma_Polyhedra_Library::dimension_type space_dimension,
                 int indent = 0) {
-  using namespace std;
   using namespace Parma_Polyhedra_Library::IO_Operators;
+
   if (!pip) {
-    out << setw(indent*2) << "" << "_|_" << endl;
+    out << std::setw(indent*2) << "" << "_|_" << std::endl;
   }
   else {
-    for (PIP_Tree_Node::Artificial_Parameter_Sequence::const_iterator
+    for (PPL::PIP_Tree_Node::Artificial_Parameter_Sequence::const_iterator
            i = pip->art_parameter_begin(),
            i_end = pip->art_parameter_end();
          i != i_end;
          ++i) {
-      out << setw(indent*2) << "" << "Parameter "
-          << Linear_Expression(Variable(space_dimension++))
-          << " = " << *i << endl;
+      out << std::setw(indent*2) << "" << "Parameter "
+          << PPL::Linear_Expression(PPL::Variable(space_dimension++))
+          << " = " << *i << std::endl;
     }
-    const Constraint_System &constraints = pip->constraints();
+    const PPL::Constraint_System& constraints = pip->constraints();
     const bool constraints_empty = constraints.empty();
     if (!constraints_empty) {
-      out << setw(indent*2) << "" << "if ";
-      for (Constraint_System::const_iterator
+      out << std::setw(indent*2) << "" << "if ";
+      for (PPL::Constraint_System::const_iterator
              cs_begin = constraints.begin(),
              cs_end = constraints.end(),
-             i = cs_begin; i != cs_end; ++i)
+             i = cs_begin; i != cs_end; ++i) {
         out << ((i == cs_begin) ? "" : " and ") << *i;
-      out << " then" << endl;
+      }
+      out << " then" << std::endl;
     }
-    const PIP_Decision_Node* const decision_node_p = pip->as_decision();
+    const PPL::PIP_Decision_Node* const decision_node_p = pip->as_decision();
     if (decision_node_p) {
       pip_display_sol(out, decision_node_p->child_node(true),
                       parameters, vars, space_dimension, indent+1);
-      out << setw(indent*2) << "" << "else" << endl;
+      out << std::setw(indent*2) << "" << "else" << std::endl;
       pip_display_sol(out, decision_node_p->child_node(false),
                       parameters, vars, space_dimension, indent+1);
     }
     else {
-      const PIP_Solution_Node* const solution_node_p = pip->as_solution();
-      out << setw(indent*2 + (constraints_empty ? 0 : 2)) << "" << "{";
-      for (Variables_Set::const_iterator
+      const PPL::PIP_Solution_Node* const solution_node_p = pip->as_solution();
+      out << std::setw(indent*2 + (constraints_empty ? 0 : 2)) << "" << "{";
+      for (PPL::Variables_Set::const_iterator
              v_begin = vars.begin(),
              v_end = vars.end(),
-             i = v_begin; i != v_end; ++i)
+             i = v_begin; i != v_end; ++i) {
         out << ((i == v_begin) ? "" : " ; ")
-            << solution_node_p->parametric_values(Variable(*i));
-      out << "}" << endl;
+            << solution_node_p->parametric_values(PPL::Variable(*i));
+      }
+      out << "}" << std::endl;
       if (!constraints_empty) {
-        out << setw(indent*2) << "" << "else" << endl;
-        out << setw(indent*2 + 2) << "" << "_|_" << endl;
+        out << std::setw(indent*2) << "" << "else" << std::endl;
+        out << std::setw(indent*2 + 2) << "" << "_|_" << std::endl;
       }
     }
   }
@@ -195,8 +193,9 @@ public:
     const PPL::Variables_Set& params = pip.parameter_space_dimensions();
     PPL::Variables_Set vars;
     for (PPL::dimension_type i = 0; i < pip.space_dimension(); ++i) {
-      if (params.count(i) == 0)
+      if (params.count(i) == 0) {
         vars.insert(i);
+      }
     }
     const PPL::PIP_Tree solution = pip.solution();
     pip_display_sol(out, solution, params, vars, pip.space_dimension());
@@ -217,28 +216,35 @@ public:
     pip.add_space_dimensions_and_embed(num_vars, num_params);
     for (PPL::dimension_type k = 0, i = 0; i < num_constraints; ++i) {
       PPL::Linear_Expression expr;
-      for (PPL::dimension_type j = 0; j < num_vars + num_params; ++j)
+      for (PPL::dimension_type j = 0; j < num_vars + num_params; ++j) {
         add_mul_assign(expr, constraints[k++], PPL::Variable(j));
+      }
       expr += constraints[k++];
-      if (constraint_type[i])
+      if (constraint_type[i]) {
         pip.add_constraint(PPL::Constraint(expr >= 0));
-      else
+      }
+      else {
         pip.add_constraint(PPL::Constraint(expr == 0));
+      }
     }
     if (num_params > 0) {
       for (PPL::dimension_type k = 0, i = 0; i < num_ctx_rows; ++i) {
         PPL::Linear_Expression expr;
-        for (PPL::dimension_type j = 0; j < num_params; ++j)
+        for (PPL::dimension_type j = 0; j < num_params; ++j) {
           add_mul_assign(expr, context[k++], PPL::Variable(num_vars+j));
+        }
         expr += context[k++];
-        if (ctx_type[i])
+        if (ctx_type[i]) {
           pip.add_constraint(PPL::Constraint(expr >= 0));
-        else
+        }
+        else {
           pip.add_constraint(PPL::Constraint(expr == 0));
+        }
       }
     }
-    if (bignum_column != PPL::not_a_dimension())
+    if (bignum_column != PPL::not_a_dimension()) {
       pip.set_big_parameter_dimension(bignum_column);
+    }
     return true;
   }
 
@@ -334,12 +340,15 @@ public:
   }
 
   bool read(std::istream& in) {
-    if (!expect(in, '('))
+    if (!expect(in, '(')) {
       return false;
-    if (!expect(in, '('))
+    }
+    if (!expect(in, '(')) {
       return false;
-    if (!read_comment(in))
+    }
+    if (!read_comment(in)) {
       return false;
+    }
 
     PPL::dimension_type num_vars;
     PPL::dimension_type num_params;
@@ -364,24 +373,31 @@ public:
       return false;
     }
 
-    if (!expect(in, '('))
+    if (!expect(in, '(')) {
       return false;
+    }
     const PPL::dimension_type constraint_width = num_vars+num_params+1;
     Coeff_Vector constraints(num_constraints * constraint_width);
     Int_Vector constraint_type(num_constraints);
-    for (PPL::dimension_type i = 0; i < num_constraints; ++i)
+    for (PPL::dimension_type i = 0; i < num_constraints; ++i) {
       constraint_type[i] = 1;
-    for (PPL::dimension_type i = 0; i < num_constraints; ++i)
-      if (!read_vector(in, i, constraint_width, num_vars, constraints))
+    }
+    for (PPL::dimension_type i = 0; i < num_constraints; ++i) {
+      if (!read_vector(in, i, constraint_width, num_vars, constraints)) {
         return false;
+      }
+    }
 
     Coeff_Vector context(num_ctx_rows * (1+num_params));
     Int_Vector ctx_type(num_ctx_rows);
-    for (PPL::dimension_type i = 0; i < num_ctx_rows; ++i)
+    for (PPL::dimension_type i = 0; i < num_ctx_rows; ++i) {
       ctx_type[i] = 1;
-    for (PPL::dimension_type i = 0; i < num_ctx_rows; ++i)
-      if (!read_vector(in, i, num_params+1, num_params, context))
+    }
+    for (PPL::dimension_type i = 0; i < num_ctx_rows; ++i) {
+      if (!read_vector(in, i, num_params+1, num_params, context)) {
         return false;
+      }
+    }
 
     const bool result = update_pip(num_vars, num_params,
                                    num_constraints, num_ctx_rows,
@@ -397,14 +413,18 @@ protected:
     int count = 1;
     do {
       char c;
-      if (!in.get(c))
+      if (!in.get(c)) {
         return false;
-      if (c == '(')
+      }
+      if (c == '(') {
         ++count;
-      else if (c == ')')
+      }
+      else if (c == ')') {
         --count;
-      if (count > 0)
+      }
+      if (count > 0) {
         comment += c;
+      }
     } while (count > 0);
     return true;
   }
@@ -422,29 +442,35 @@ protected:
                           PPL::dimension_type row_size,
                           PPL::dimension_type cst_col,
                           Coeff_Vector& tab) {
-    if (!expect(in, '#'))
+    if (!expect(in, '#')) {
       return false;
-    if (!expect(in, '['))
+    }
+    if (!expect(in, '[')) {
       return false;
+    }
     std::string s;
     getline(in, s, ']');
-    if (in.fail())
+    if (in.fail()) {
       return false;
+    }
     std::istringstream iss(s);
     const PPL::dimension_type start_index = row_index * row_size;
     PPL::dimension_type k = start_index;
     for (PPL::dimension_type i = 0; i < cst_col; ++i, ++k) {
       iss >> tab[k];
-      if (iss.fail())
+      if (iss.fail()) {
         return false;
+      }
     }
     iss >> tab[start_index + row_size - 1];
-    if (iss.fail())
+    if (iss.fail()) {
       return false;
+    }
     for (PPL::dimension_type i = cst_col + 1; i < row_size; ++i, ++k) {
       iss >> tab[k];
-      if (iss.fail())
+      if (iss.fail()) {
         return false;
+      }
     }
     return true;
   }
@@ -538,13 +564,14 @@ std::istream* input_stream_p = 0;
 
 void
 set_input(const char* file_name) {
-  if (input_stream_p && *input_stream_p != std::cin)
+  if (input_stream_p && (input_stream_p != &std::cin)) {
     delete input_stream_p;
-
+  }
   if (file_name) {
     input_stream_p = new std::ifstream(file_name, std::ios_base::in);
-    if (!*input_stream_p)
+    if (!*input_stream_p) {
       fatal("cannot open input file `%s'", file_name);
+    }
     input_file_name = file_name;
   }
   else {
@@ -558,15 +585,16 @@ std::ostream* output_stream_p = 0;
 
 void
 set_output(const char* file_name) {
-  if (output_stream_p && *output_stream_p != std::cout)
+  if (output_stream_p && (output_stream_p != &std::cout)) {
     delete output_stream_p;
-
+  }
   if (file_name) {
     output_stream_p = new std::ofstream(file_name,
                                         std::ios_base::out
                                         | std::ios_base::app);
-    if (!*output_stream_p)
+    if (!*output_stream_p) {
       fatal("cannot open output file `%s'", file_name);
+    }
     output_file_name = file_name;
   }
   else {
@@ -606,13 +634,14 @@ void
 limit_virtual_memory(const unsigned long bytes) {
   struct rlimit t;
 
-  if (getrlimit(RLIMIT_AS, &t) != 0)
+  if (getrlimit(RLIMIT_AS, &t) != 0) {
     fatal("getrlimit failed: %s", strerror(errno));
-
+  }
   if (bytes < t.rlim_cur) {
     t.rlim_cur = bytes;
-    if (setrlimit(RLIMIT_AS, &t) != 0)
+    if (setrlimit(RLIMIT_AS, &t) != 0) {
       fatal("setrlimit failed: %s", strerror(errno));
+    }
   }
 }
 
@@ -635,9 +664,9 @@ process_options(int argc, char* argv[]) {
     const int c = getopt(argc, argv, OPTION_LETTERS);
 #endif
 
-    if (c == EOF)
+    if (c == EOF) {
       break;
-
+    }
     char* endptr;
     switch (c) {
     case 0:
@@ -653,12 +682,15 @@ process_options(int argc, char* argv[]) {
       {
         const unsigned long MEGA = 1024U*1024U;
         const long l = strtol(optarg, &endptr, 10);
-        if (*endptr || l < 0)
+        if (*endptr || l < 0) {
           fatal("a non-negative integer must follow `-R'");
-        else if (static_cast<unsigned long>(l) > ULONG_MAX/MEGA)
+        }
+        else if (static_cast<unsigned long>(l) > ULONG_MAX/MEGA) {
           max_bytes_of_virtual_memory = ULONG_MAX;
-        else
+        }
+        else {
           max_bytes_of_virtual_memory = static_cast<unsigned long>(l)*MEGA;
+        }
       }
       break;
 
@@ -684,8 +716,9 @@ process_options(int argc, char* argv[]) {
 
     case 'i':
       loop_iterations = strtol(optarg, &endptr, 10);
-      if (*endptr || loop_iterations < 1)
+      if (*endptr || loop_iterations < 1) {
         fatal("a positive integer must follow `-i'");
+      }
       break;
 
 #if defined(USE_PPL)
@@ -726,22 +759,25 @@ process_options(int argc, char* argv[]) {
     }
   }
 
-  if (argc - optind > 1)
+  if (argc - optind > 1) {
     // We have multiple input files.
     fatal("at most one input file is accepted");
-
+  }
   // We have one input files.
-  if (optind < argc)
+  if (optind < argc) {
     input_file_name = argv[optind];
-  else
+  }
+  else {
     // If no input files have been specified: we will read from standard input.
     assert(input_file_name == 0);
+  }
 }
 
 void
 maybe_start_clock() {
-  if (print_timings)
+  if (print_timings) {
     start_clock();
+  }
 }
 
 void
@@ -758,22 +794,23 @@ main(int argc, char* argv[]) try {
   program_name = argv[0];
 
 #if defined(USE_PPL)
-  if (strcmp(PPL_VERSION, PPL::version()) != 0)
+  if (strcmp(PPL_VERSION, PPL::version()) != 0) {
     fatal("was compiled with PPL version %s, but linked with version %s",
           PPL_VERSION, PPL::version());
-
-  if (verbose)
+  }
+  if (verbose) {
     std::cerr << "Parma Polyhedra Library version:\n" << PPL::version()
               << "\n\nParma Polyhedra Library banner:\n" << PPL::banner()
               << std::endl;
+  }
 #endif
 
   // Process command line options.
   process_options(argc, argv);
 
-  if (max_bytes_of_virtual_memory > 0)
+  if (max_bytes_of_virtual_memory > 0) {
     limit_virtual_memory(max_bytes_of_virtual_memory);
-
+  }
   // Set up the input and output streams.
   set_input(input_file_name);
   set_output(output_file_name);
@@ -781,13 +818,15 @@ main(int argc, char* argv[]) try {
 //  POLYHEDRON_TYPE ph;
 //  Representation rep = read_polyhedron(input(), ph);
   std::auto_ptr<PIP_Parser> parser;
-  if (piplib_format)
+  if (piplib_format) {
     parser.reset(new PIP_PipLib_Parser);
-  else
+  }
+  else{
     parser.reset(new PIP_PolyLib_Parser);
-  if (!parser->read(*input_stream_p))
+  }
+  if (!parser->read(*input_stream_p)) {
     return 1;
-
+  }
   maybe_start_clock();
 
   const PPL::PIP_Problem& pip = parser->problem();
