@@ -1,6 +1,6 @@
 /* Bit_Matrix class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2016 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -33,7 +33,7 @@ site: http://bugseng.com/products/ppl/ . */
 namespace PPL = Parma_Polyhedra_Library;
 
 PPL::Bit_Matrix&
-PPL::Bit_Matrix::operator=(const Bit_Matrix& y){
+PPL::Bit_Matrix::operator=(const Bit_Matrix& y) {
   rows = y.rows;
   row_size = y.row_size;
   PPL_ASSERT(OK());
@@ -43,9 +43,9 @@ PPL::Bit_Matrix::operator=(const Bit_Matrix& y){
 void
 PPL::Bit_Matrix::sort_rows() {
   const dimension_type num_elems = rows.size();
-  if (num_elems < 2)
+  if (num_elems < 2) {
     return;
-
+  }
   // Build the function objects implementing indirect sort comparison,
   // indirect unique comparison and indirect swap operation.
   using namespace Implementation;
@@ -82,16 +82,18 @@ PPL::Bit_Matrix::add_recycled_row(Bit_Row& row) {
     dimension_type i = new_rows_size-1;
     new_rows[i].m_swap(row);
     // Steal the old rows.
-    while (i-- > 0)
+    while (i-- > 0) {
       new_rows[i].m_swap(rows[i]);
+    }
     // Put the new rows into place.
     using std::swap;
     swap(rows, new_rows);
   }
-  else
+  else {
     // Reallocation will NOT take place: append an empty row
     // and swap it with the new row.
     rows.insert(rows.end(), Bit_Row())->m_swap(row);
+  }
   PPL_ASSERT(OK());
 }
 
@@ -101,10 +103,12 @@ PPL::Bit_Matrix::transpose() {
   const dimension_type nrows = num_rows();
   const dimension_type ncols = num_columns();
   Bit_Matrix tmp(ncols, nrows);
-  for (dimension_type i = nrows; i-- > 0; )
+  for (dimension_type i = nrows; i-- > 0; ) {
     for (unsigned long j = x[i].last();
-         j != C_Integer<unsigned long>::max; j = x[i].prev(j))
+         j != C_Integer<unsigned long>::max; j = x[i].prev(j)) {
       tmp[j].set(i);
+    }
+  }
   m_swap(tmp);
   PPL_ASSERT(OK());
 }
@@ -114,10 +118,12 @@ PPL::Bit_Matrix::transpose_assign(const Bit_Matrix& y) {
   const dimension_type y_num_rows = y.num_rows();
   const dimension_type y_num_columns = y.num_columns();
   Bit_Matrix tmp(y_num_columns, y_num_rows);
-  for (dimension_type i = y_num_rows; i-- > 0; )
+  for (dimension_type i = y_num_rows; i-- > 0; ) {
     for (unsigned long j = y[i].last();
-         j != C_Integer<unsigned long>::max; j = y[i].prev(j))
+         j != C_Integer<unsigned long>::max; j = y[i].prev(j)) {
       tmp[j].set(i);
+    }
+  }
   m_swap(tmp);
   PPL_ASSERT(OK());
 }
@@ -131,8 +137,9 @@ PPL::Bit_Matrix::resize(dimension_type new_n_rows,
     const dimension_type num_preserved_rows
       = std::min(old_num_rows, new_n_rows);
     Bit_Matrix& x = *this;
-    for (dimension_type i = num_preserved_rows; i-- > 0; )
+    for (dimension_type i = num_preserved_rows; i-- > 0; ) {
       x[i].clear_from(new_n_columns);
+    }
   }
   row_size = new_n_columns;
   if (new_n_rows > old_num_rows) {
@@ -142,19 +149,22 @@ PPL::Bit_Matrix::resize(dimension_type new_n_rows,
       new_rows.reserve(compute_capacity(new_n_rows, max_num_rows()));
       new_rows.insert(new_rows.end(), new_n_rows, Bit_Row());
       // Steal the old rows.
-      for (dimension_type i = old_num_rows; i-- > 0; )
+      for (dimension_type i = old_num_rows; i-- > 0; ) {
         new_rows[i].m_swap(rows[i]);
+      }
       // Put the new vector into place.
       using std::swap;
       swap(rows, new_rows);
     }
-    else
+    else {
       // Reallocation will NOT take place.
       rows.insert(rows.end(), new_n_rows - old_num_rows, Bit_Row());
+    }
   }
-  else if (new_n_rows < old_num_rows)
+  else if (new_n_rows < old_num_rows) {
     // Drop some rows.
     rows.resize(new_n_rows);
+  }
 
   PPL_ASSERT(OK());
 }
@@ -166,8 +176,9 @@ PPL::Bit_Matrix::ascii_dump(std::ostream& s) const {
   s << num_rows() << separator << 'x' << separator
     << num_columns() << "\n";
   for (dimension_type i = 0; i < num_rows(); ++i) {
-    for (dimension_type j = 0; j < num_columns(); ++j)
+    for (dimension_type j = 0; j < num_columns(); ++j) {
       s << x[i][j] << separator;
+    }
     s << "\n";
   }
 }
@@ -180,25 +191,31 @@ PPL::Bit_Matrix::ascii_load(std::istream& s) {
   dimension_type nrows;
   dimension_type ncols;
   std::string str;
-  if (!(s >> nrows))
+  if (!(s >> nrows)) {
     return false;
-  if (!(s >> str) || str != "x")
+  }
+  if (!(s >> str) || str != "x") {
     return false;
-  if (!(s >> ncols))
+  }
+  if (!(s >> ncols)) {
     return false;
+  }
   resize(nrows, ncols);
 
-  for (dimension_type i = 0; i < num_rows(); ++i)
+  for (dimension_type i = 0; i < num_rows(); ++i) {
     for (dimension_type j = 0; j < num_columns(); ++j) {
       int bit;
-      if (!(s >> bit))
+      if (!(s >> bit)) {
         return false;
-      if (bit != 0)
+      }
+      if (bit != 0) {
         x[i].set(j);
-      else
+      }
+      else {
         x[i].clear(j);
+      }
     }
-
+  }
   // Check invariants.
   PPL_ASSERT(OK());
   return true;
@@ -207,8 +224,9 @@ PPL::Bit_Matrix::ascii_load(std::istream& s) {
 PPL::memory_size_type
 PPL::Bit_Matrix::external_memory_in_bytes() const {
   memory_size_type n = rows.capacity() * sizeof(Dense_Row);
-  for (dimension_type i = num_rows(); i-- > 0; )
+  for (dimension_type i = num_rows(); i-- > 0; ) {
     n += rows[i].external_memory_in_bytes();
+  }
   return n;
 }
 
@@ -222,8 +240,9 @@ PPL::Bit_Matrix::OK() const {
   const Bit_Matrix& x = *this;
   for (dimension_type i = num_rows(); i-- > 0; ) {
     const Bit_Row& row = x[i];
-    if (!row.OK())
+    if (!row.OK()) {
       return false;
+    }
     else if (row.last() != C_Integer<unsigned long>::max
              && row.last() >= row_size) {
 #ifndef NDEBUG
@@ -243,9 +262,11 @@ PPL::Bit_Matrix::OK() const {
 bool
 PPL::Bit_Matrix::check_sorted() const {
   const Bit_Matrix& x = *this;
-  for (dimension_type i = num_rows(); i-- > 1; )
-    if (compare(x[i-1], x[i]) > 0)
+  for (dimension_type i = num_rows(); i-- > 1; ) {
+    if (compare(x[i-1], x[i]) > 0) {
       return false;
+    }
+  }
   return true;
 }
 #endif
@@ -255,11 +276,13 @@ bool
 PPL::operator==(const Bit_Matrix& x, const Bit_Matrix& y) {
   const dimension_type x_num_rows = x.num_rows();
   if (x_num_rows != y.num_rows()
-      || x.num_columns() != y.num_columns())
+      || x.num_columns() != y.num_columns()) {
     return false;
-  for (dimension_type i = x_num_rows; i-- > 0; )
-    if (x[i] != y[i])
+  }
+  for (dimension_type i = x_num_rows; i-- > 0; ) {
+    if (x[i] != y[i]) {
       return false;
+    }
+  }
   return true;
 }
-
