@@ -1,6 +1,6 @@
 /* CO_Tree class implementation.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2016 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -34,8 +34,10 @@ PPL::CO_Tree::external_memory_in_bytes() const {
     memory_size += (reserved_size + 1)*sizeof(data[0]);
     // Add the size of indexes[]
     memory_size += (reserved_size + 2)*sizeof(indexes[0]);
-    for (const_iterator itr = begin(), itr_end = end(); itr != itr_end; ++itr)
+    for (const_iterator itr = begin(), itr_end = end();
+         itr != itr_end; ++itr) {
       memory_size += PPL::external_memory_in_bytes(*itr);
+    }
   }
   return memory_size;
 }
@@ -49,35 +51,40 @@ PPL::CO_Tree::insert(iterator itr, dimension_type key1) {
     return iterator(*this);
   }
 
-  if (itr == end())
+  if (itr == end()) {
     return insert(key1);
+  }
 
   iterator candidate1 = bisect_near(itr, key1);
 
-  if (key1 == candidate1.index())
+  if (key1 == candidate1.index()) {
     return candidate1;
+  }
 
   dimension_type candidate2_index = dfs_index(candidate1);
 
   if (key1 < candidate1.index()) {
     --candidate2_index;
-    while (indexes[candidate2_index] == unused_index)
+    while (indexes[candidate2_index] == unused_index) {
       --candidate2_index;
+    }
   }
   else {
     ++candidate2_index;
-    while (indexes[candidate2_index] == unused_index)
+    while (indexes[candidate2_index] == unused_index) {
       ++candidate2_index;
+    }
   }
 
   tree_iterator candidate1_node(candidate1, *this);
 
   PPL_ASSERT(candidate2_index <= reserved_size + 1);
 
-  if (candidate2_index == 0 || candidate2_index > reserved_size)
+  if (candidate2_index == 0 || candidate2_index > reserved_size) {
     // Use candidate1
     return iterator(insert_precise(key1, Coefficient_zero(),
                                    candidate1_node));
+  }
 
   tree_iterator candidate2_node(*this, candidate2_index);
 
@@ -112,8 +119,9 @@ PPL::CO_Tree::insert(iterator itr, dimension_type key1,
     return iterator(*this);
   }
 
-  if (itr == end())
+  if (itr == end()) {
     return insert(key1, data1);
+  }
 
   iterator candidate1 = bisect_near(itr, key1);
 
@@ -126,20 +134,25 @@ PPL::CO_Tree::insert(iterator itr, dimension_type key1,
 
   if (key1 < candidate1.index()) {
     --candidate2_index;
-    while (indexes[candidate2_index] == unused_index)
+    while (indexes[candidate2_index] == unused_index) {
       --candidate2_index;
+    }
+
   }
   else {
     ++candidate2_index;
-    while (indexes[candidate2_index] == unused_index)
+    while (indexes[candidate2_index] == unused_index) {
       ++candidate2_index;
+    }
+
   }
 
   tree_iterator candidate1_node(candidate1, *this);
 
-  if (candidate2_index == 0 || candidate2_index > reserved_size)
+  if (candidate2_index == 0 || candidate2_index > reserved_size) {
     // Use candidate1
     return iterator(insert_precise(key1, data1, candidate1_node));
+  }
 
   tree_iterator candidate2_node(*this, candidate2_index);
 
@@ -165,29 +178,35 @@ PPL::CO_Tree::insert(iterator itr, dimension_type key1,
 void
 PPL::CO_Tree::erase_element_and_shift_left(dimension_type key) {
   iterator itr = erase(key);
-  if (itr == end())
+  if (itr == end()) {
     return;
+  }
   const dimension_type i = dfs_index(itr);
   dimension_type* p = indexes + i;
   const dimension_type* const p_end = indexes + (reserved_size + 1);
-  for ( ; p != p_end; ++p)
-    if (*p != unused_index)
+  for ( ; p != p_end; ++p) {
+    if (*p != unused_index) {
       --(*p);
+    }
+  }
   PPL_ASSERT(OK());
 }
 
 void
 PPL::CO_Tree::increase_keys_from(dimension_type key, dimension_type n) {
-  if (empty())
+  if (empty()) {
     return;
+  }
   dimension_type* p = indexes + reserved_size;
-  while (*p == unused_index)
+  while (*p == unused_index) {
     --p;
+  }
   while (p != indexes && *p >= key) {
     *p += n;
     --p;
-    while (*p == unused_index)
+    while (*p == unused_index) {
       --p;
+    }
   }
   PPL_ASSERT(OK());
 }
@@ -205,16 +224,19 @@ PPL::CO_Tree::bisect_in(dimension_type first, dimension_type last,
     dimension_type half = (first + last) / 2;
     dimension_type new_half = half;
 
-    while (indexes[new_half] == unused_index)
+    while (indexes[new_half] == unused_index) {
       ++new_half;
+    }
 
-    if (indexes[new_half] == key)
+    if (indexes[new_half] == key) {
       return new_half;
+    }
 
     if (indexes[new_half] > key) {
 
-      while (indexes[half] == unused_index)
+      while (indexes[half] == unused_index) {
         --half;
+      }
 
       last = half;
 
@@ -222,8 +244,9 @@ PPL::CO_Tree::bisect_in(dimension_type first, dimension_type last,
     else {
 
       ++new_half;
-      while (indexes[new_half] == unused_index)
+      while (indexes[new_half] == unused_index) {
         ++new_half;
+      }
 
       first = new_half;
     }
@@ -241,8 +264,9 @@ PPL::CO_Tree::bisect_near(dimension_type hint, dimension_type key) const {
   PPL_ASSERT(hint <= reserved_size);
   PPL_ASSERT(indexes[hint] != unused_index);
 
-  if (indexes[hint] == key)
+  if (indexes[hint] == key) {
     return hint;
+  }
 
   dimension_type new_hint;
   dimension_type offset = 1;
@@ -257,28 +281,34 @@ PPL::CO_Tree::bisect_near(dimension_type hint, dimension_type key) const {
         new_hint = hint;
         hint = 1;
         // The searched element is in [hint,new_hint).
-        while (indexes[hint] == unused_index)
+        while (indexes[hint] == unused_index) {
           ++hint;
-        if (indexes[hint] >= key)
+        }
+
+        if (indexes[hint] >= key) {
           return hint;
+        }
         // The searched element is in (hint,new_hint) and both indexes point
         // to valid elements.
         break;
       }
-      else
+      else {
         new_hint = hint - offset;
+      }
 
       PPL_ASSERT(new_hint > 0);
       PPL_ASSERT(new_hint <= reserved_size);
 
       // Find the element at `new_hint' (or the first after it).
-      while (indexes[new_hint] == unused_index)
+      while (indexes[new_hint] == unused_index) {
         ++new_hint;
+      }
 
       PPL_ASSERT(new_hint <= hint);
 
-      if (indexes[new_hint] == key)
+      if (indexes[new_hint] == key) {
         return new_hint;
+      }
       else
         if (indexes[new_hint] < key) {
           // The searched element is in (new_hint,hint)
@@ -301,33 +331,39 @@ PPL::CO_Tree::bisect_near(dimension_type hint, dimension_type key) const {
         // The searched element is in (hint,reserved_size+1).
         new_hint = reserved_size;
         // The searched element is in (hint,new_hint].
-        while (indexes[new_hint] == unused_index)
+        while (indexes[new_hint] == unused_index) {
           --new_hint;
-        if (indexes[new_hint] <= key)
+        }
+        if (indexes[new_hint] <= key) {
           return new_hint;
+        }
         // The searched element is in (hint,new_hint) and both indexes point
         // to valid elements.
         break;
       }
-      else
+      else {
         new_hint = hint + offset;
+      }
 
       PPL_ASSERT(new_hint > 0);
       PPL_ASSERT(new_hint <= reserved_size);
 
       // Find the element at `new_hint' (or the first after it).
-      while (indexes[new_hint] == unused_index)
+      while (indexes[new_hint] == unused_index) {
         --new_hint;
+      }
 
       PPL_ASSERT(hint <= new_hint);
 
-      if (indexes[new_hint] == key)
+      if (indexes[new_hint] == key) {
         return new_hint;
-      else
-        if (indexes[new_hint] > key)
+      }
+      else {
+        if (indexes[new_hint] > key) {
           // The searched element is in (hint,new_hint).
           break;
-
+        }
+      }
       hint = new_hint;
       offset *= 2;
     }
@@ -340,15 +376,19 @@ PPL::CO_Tree::bisect_near(dimension_type hint, dimension_type key) const {
   PPL_ASSERT(indexes[new_hint] != unused_index);
 
   ++hint;
-  while (indexes[hint] == unused_index)
+  while (indexes[hint] == unused_index) {
     ++hint;
+  }
 
-  if (hint == new_hint)
+  if (hint == new_hint) {
     return hint;
+  }
 
   --new_hint;
-  while (indexes[new_hint] == unused_index)
+
+  while (indexes[new_hint] == unused_index) {
     --new_hint;
+  }
 
   PPL_ASSERT(hint <= new_hint);
   PPL_ASSERT(indexes[hint] != unused_index);
@@ -382,9 +422,9 @@ PPL::CO_Tree::insert_precise(dimension_type key1,
   const bool invalidating
     = (data <= &data1) && (&data1 < data + (reserved_size + 1));
 
-  if (!invalidating)
+  if (!invalidating) {
     return insert_precise_aux(key1, data1, itr);
-
+  }
   // `data1' could be invalidated by the insert, because it is
   // a coefficient of this row. Avoid the issue by copying it.
   data_type data1_copy = data1;
@@ -437,13 +477,15 @@ PPL::CO_Tree::insert_precise_aux(dimension_type key1,
   ++size_;
 
   if (!itr.is_leaf()) {
-    if (key1 < itr.index())
+    if (key1 < itr.index()) {
       itr.get_left_child();
-    else
+    }
+    else {
       itr.get_right_child();
+    }
     PPL_ASSERT(itr.index() == unused_index);
 
-    new (&(*itr)) data_type(data1);
+    new(&(*itr)) data_type(data1);
     // Set the index only if the construction was successful.
     itr.index() = key1;
   }
@@ -486,11 +528,12 @@ PPL::CO_Tree::erase(tree_iterator itr) {
   }
 
 #ifndef NDEBUG
-  if (size_ > 1)
+  if (size_ > 1) {
     PPL_ASSERT(!is_less_than_ratio(size_ - 1, reserved_size,
                                    min_density_percent)
                || is_greater_than_ratio(size_ - 1, reserved_size/2,
                                         max_density_percent));
+  }
 #endif
 
   const dimension_type deleted_key = itr.index();
@@ -499,19 +542,22 @@ PPL::CO_Tree::erase(tree_iterator itr) {
   while (true) {
     dimension_type& current_key  = itr.index();
     data_type&      current_data = *itr;
-    if (itr.is_leaf())
+    if (itr.is_leaf()) {
       break;
+    }
     itr.get_left_child();
-    if (itr.index() != unused_index)
+    if (itr.index() != unused_index) {
       // The left child has a value.
       itr.follow_right_children_with_value();
+    }
     else {
       // The left child has not a value, try the right child.
       itr.get_parent();
       itr.get_right_child();
-      if (itr.index() != unused_index)
+      if (itr.index() != unused_index) {
         // The right child has a value.
         itr.follow_left_children_with_value();
+      }
       else {
         // The right child has not a value, too.
         itr.get_parent();
@@ -531,16 +577,18 @@ PPL::CO_Tree::erase(tree_iterator itr) {
 
   itr = rebalance(itr, 0, Coefficient_zero());
 
-  if (itr.get_offset() < deleted_node.get_offset())
+  if (itr.get_offset() < deleted_node.get_offset()) {
     // deleted_node is an ancestor of itr
     itr = deleted_node;
+  }
 
   itr.go_down_searching_key(deleted_key);
 
   iterator result(itr);
 
-  if (result.index() < deleted_key)
+  if (result.index() < deleted_key) {
     ++result;
+  }
 
   PPL_ASSERT(OK());
   PPL_ASSERT(result == end() || result.index() > deleted_key);
@@ -583,8 +631,9 @@ PPL::CO_Tree::init(dimension_type n) {
     reserved_size = new_reserved_size;
 
     // Mark all pairs as unused.
-    for (dimension_type i = 1; i <= reserved_size; ++i)
+    for (dimension_type i = 1; i <= reserved_size; ++i) {
       indexes[i] = unused_index;
+    }
 
     // These are used as markers by iterators.
     indexes[0] = 0;
@@ -601,8 +650,9 @@ PPL::CO_Tree::destroy() {
 
   if (reserved_size != 0) {
     for (dimension_type i = 1; i <= reserved_size; ++i) {
-      if (indexes[i] != unused_index)
+      if (indexes[i] != unused_index) {
         data[i].~data_type();
+      }
     }
 
     delete[] indexes;
@@ -613,42 +663,51 @@ PPL::CO_Tree::destroy() {
 bool
 PPL::CO_Tree::structure_OK() const {
 
-  if (size_ > reserved_size)
+  if (size_ > reserved_size) {
     return false;
+  }
 
   if (reserved_size == 0) {
-    if (indexes != NULL)
+    if (indexes != NULL) {
       return false;
-    if (data != NULL)
+    }
+    if (data != NULL) {
       return false;
-    if (max_depth != 0)
+    }
+    if (max_depth != 0) {
       return false;
+    }
 
     return true;
   }
 
-  if (reserved_size < 3)
+  if (reserved_size < 3) {
     return false;
+  }
+  if (reserved_size != (static_cast<dimension_type>(1) << max_depth) - 1) {
+    return false;
+  }
 
-  if (reserved_size != (static_cast<dimension_type>(1) << max_depth) - 1)
+  if (data == NULL) {
     return false;
+  }
 
-  if (data == NULL)
+  if (indexes == NULL) {
     return false;
+  }
 
-  if (indexes == NULL)
-    return false;
-
-  if (max_depth == 0)
+  if (max_depth == 0) {
     return false;
+  }
 
   if (size_ == 0) {
 
     // This const_cast could be removed by adding a const_tree_iterator,
     // but it would add much code duplication without a real need.
     tree_iterator itr(*const_cast<CO_Tree*>(this));
-    if (itr.index() != unused_index)
+    if (itr.index() != unused_index) {
       return false;
+    }
 
   }
   else {
@@ -656,10 +715,11 @@ PPL::CO_Tree::structure_OK() const {
     // but it would add much code duplication without a real need.
     tree_iterator itr(*const_cast<CO_Tree*>(this));
     const dimension_type real_size = count_used_in_subtree(itr);
-    if (real_size != size_)
+    if (real_size != size_) {
       // There are \p real_size elements in the tree that are reachable by the
       // root, but size is \p size.
       return false;
+    }
   }
 
   if (size_ != 0) {
@@ -669,18 +729,21 @@ PPL::CO_Tree::structure_OK() const {
     if (itr != itr_end) {
       dimension_type last_index = itr.index();
       for (++itr; itr != itr_end; ++itr) {
-        if (last_index >= itr.index())
+        if (last_index >= itr.index()) {
           // Found index \p itr->first after index \p last_index.
           return false;
+        }
         last_index = itr.index();
       }
     }
   }
 
-  if (const_iterator(cached_end) != const_iterator(*this, reserved_size + 1))
+  if (const_iterator(cached_end) != const_iterator(*this, reserved_size + 1)) {
     return false;
-  if (cached_const_end != const_iterator(*this, reserved_size + 1))
+  }
+  if (cached_const_end != const_iterator(*this, reserved_size + 1)) {
     return false;
+  }
 
   return true;
 }
@@ -688,29 +751,33 @@ PPL::CO_Tree::structure_OK() const {
 bool
 PPL::CO_Tree::OK() const {
 
-  if (!structure_OK())
+  if (!structure_OK()) {
     return false;
-
+  }
   {
     dimension_type real_size = 0;
 
-    for (const_iterator itr = begin(), itr_end = end(); itr != itr_end; ++itr)
+    for (const_iterator itr = begin(), itr_end = end(); itr != itr_end; ++itr) {
       ++real_size;
+    }
 
-    if (real_size != size_)
+    if (real_size != size_) {
       // There are \p real_size elements in the tree, but size is \p size.
       return false;
+    }
   }
 
   if (reserved_size > 0) {
     if (is_greater_than_ratio(size_, reserved_size, max_density_percent)
-        && reserved_size != 3)
+        && reserved_size != 3) {
       // Found too high density.
       return false;
+    }
     if (is_less_than_ratio(size_, reserved_size, min_density_percent)
-        && !is_greater_than_ratio(size_, reserved_size/2, max_density_percent))
+        && !is_greater_than_ratio(size_, reserved_size/2, max_density_percent)) {
       // Found too low density
       return false;
+    }
   }
 
   return true;
@@ -735,10 +802,12 @@ PPL::CO_Tree::dump_subtree(tree_iterator itr) {
     itr.get_parent();
   }
   std::cout << "At depth: " << itr.depth();
-  if (itr.index() == unused_index)
+  if (itr.index() == unused_index) {
     std::cout << " (no data)" << std::endl;
-  else
+  }
+  else {
     std::cout << " pair (" << itr.index() << "," << *itr << ")" << std::endl;
+  }
   if (!itr.is_leaf()) {
     itr.get_right_child();
     dump_subtree(itr);
@@ -771,8 +840,9 @@ PPL::CO_Tree::rebuild_bigger_tree() {
 
   for (dimension_type i = 1, j = 2; i <= reserved_size; ++i, ++j) {
     new_indexes[j] = indexes[i];
-    if (indexes[i] != unused_index)
+    if (indexes[i] != unused_index) {
       move_data_element(new_data[j], data[i]);
+    }
     ++j;
     new_indexes[j] = unused_index;
   }
@@ -813,11 +883,13 @@ PPL::CO_Tree::rebalance(tree_iterator itr, dimension_type key,
                                           << height) - 1;
   const bool deleting = itr.index() == unused_index;
   PPL_ASSERT(deleting || key != unused_index);
-  if (deleting)
+  if (deleting) {
     subtree_size = 0;
-  else
+  }
+  else {
     // The existing element and the element with index key we want to add.
     subtree_size = 2;
+  }
 
   while (is_greater_than_ratio(subtree_size, subtree_reserved_size,
                                max_density_percent
@@ -835,10 +907,12 @@ PPL::CO_Tree::rebalance(tree_iterator itr, dimension_type key,
     PPL_ASSERT(itr_depth_minus_1 != 0);
     const bool is_right_brother = itr.is_right_child();
     itr.get_parent();
-    if (is_right_brother)
+    if (is_right_brother) {
       itr.get_left_child();
-    else
+    }
+    else {
       itr.get_right_child();
+    }
     subtree_size += count_used_in_subtree(itr);
     itr.get_parent();
     PPL_ASSERT(itr.index() != unused_index);
@@ -899,7 +973,7 @@ PPL::CO_Tree
   // rightmost node with a value in the subtree. first_unused_index and
   // first_unused_data point to the rightmost unused node in the subtree.
 
-  if (add_element)
+  if (add_element) {
     while (subtree_size != 0) {
       --subtree_size;
       if (last_index_in_subtree == indexes || key > *last_index_in_subtree) {
@@ -907,7 +981,7 @@ PPL::CO_Tree
             || last_index_in_subtree != first_unused_index) {
           PPL_ASSERT(first_unused_index != indexes);
           PPL_ASSERT(*first_unused_index == unused_index);
-          new (first_unused_data) data_type(value);
+          new(first_unused_data) data_type(value);
           // Set the index only if the construction was successful.
           *first_unused_index = key;
           --first_unused_index;
@@ -934,6 +1008,7 @@ PPL::CO_Tree
         --first_unused_data;
       }
     }
+  }
   while (subtree_size != 0) {
     if (last_index_in_subtree != first_unused_index) {
       PPL_ASSERT(first_unused_index != indexes);
@@ -954,7 +1029,7 @@ PPL::CO_Tree
     --subtree_size;
   }
 
-  const ptrdiff_t distance = first_unused_index - indexes;
+  const std::ptrdiff_t distance = first_unused_index - indexes;
   PPL_ASSERT(distance >= 0);
   return static_cast<dimension_type>(distance);
 }
@@ -1008,7 +1083,7 @@ PPL::CO_Tree::redistribute_elements_in_subtree(
         PPL_ASSERT(last_used != top_i);
         PPL_ASSERT(indexes[top_i] == unused_index);
         add_element = false;
-        new (&(data[top_i])) data_type(value);
+        new(&(data[top_i])) data_type(value);
         // Set the index only if the construction was successful.
         indexes[top_i] = key;
       }
@@ -1057,14 +1132,16 @@ PPL::CO_Tree::redistribute_elements_in_subtree(
 void
 PPL::CO_Tree::move_data_from(CO_Tree& tree) {
   PPL_ASSERT(size_ == 0);
-  if (tree.size_ == 0)
+  if (tree.size_ == 0) {
     return;
+  }
 
   tree_iterator root(*this);
 
   dimension_type source_index = 1;
-  while (tree.indexes[source_index] == unused_index)
+  while (tree.indexes[source_index] == unused_index) {
     ++source_index;
+  }
 
   // This is static and with static allocation, to improve performance.
   // sizeof_to_bits(sizeof(dimension_type)) is the maximum k such that 2^k-1 is a
@@ -1141,8 +1218,9 @@ PPL::CO_Tree::move_data_from(CO_Tree& tree) {
         move_data_element(*root, tree.data[source_index]);
         PPL_ASSERT(source_index <= tree.reserved_size);
         ++source_index;
-        while (tree.indexes[source_index] == unused_index)
+        while (tree.indexes[source_index] == unused_index) {
           ++source_index;
+        }
         --stack_first_empty;
       }
       else {
@@ -1177,14 +1255,15 @@ PPL::CO_Tree::copy_data_from(const CO_Tree& x) {
 
   dimension_type i;
   try {
-    for (i = x.reserved_size; i > 0; --i)
+    for (i = x.reserved_size; i > 0; --i) {
       if (x.indexes[i] != unused_index) {
         indexes[i] = x.indexes[i];
-        new (&(data[i])) data_type(x.data[i]);
+        new(&(data[i])) data_type(x.data[i]);
       }
       else {
         PPL_ASSERT(indexes[i] == unused_index);
       }
+    }
   } catch (...) {
     // The (used) data elements in (i,x.reserved_size] have been constructed
     // successfully.
@@ -1192,9 +1271,11 @@ PPL::CO_Tree::copy_data_from(const CO_Tree& x) {
     // been constructed.
 
     // 1. Destroy the data elements that have been constructed successfully.
-    for (dimension_type j = x.reserved_size; j > i; --j)
-      if (indexes[j] != unused_index)
+    for (dimension_type j = x.reserved_size; j > i; --j) {
+      if (indexes[j] != unused_index) {
         data[j].~data_type();
+      }
+    }
 
     // 2. Deallocate index[] and data[]
     delete[] indexes;
@@ -1223,9 +1304,11 @@ PPL::CO_Tree::count_used_in_subtree(tree_iterator itr) {
   const dimension_type* current_index
     = &(itr.tree.indexes[root_index - (k - 1)]);
 
-  for (dimension_type j = 2*k - 1; j > 0; --j, ++current_index)
-    if (*current_index != unused_index)
+  for (dimension_type j = 2*k - 1; j > 0; --j, ++current_index) {
+    if (*current_index != unused_index) {
       ++n;
+    }
+  }
 
   return n;
 }
@@ -1234,30 +1317,39 @@ bool
 PPL::CO_Tree::const_iterator::OK() const {
 #if PPL_CO_TREE_EXTRA_DEBUG
   if (tree == 0) {
-    if (current_index != 0)
+    if (current_index != 0) {
       return false;
-    if (current_data != 0)
+    }
+    if (current_data != 0) {
       return false;
+    }
   }
   else
     if (tree->reserved_size == 0) {
       if (current_index != 1 + static_cast<dimension_type*>(0)
-          || current_data != 1 + static_cast<data_type*>(0))
+          || current_data != 1 + static_cast<data_type*>(0)) {
         return false;
+      }
     }
     else {
-      if (current_index <= &(tree->indexes[0]))
+      if (current_index <= &(tree->indexes[0])) {
         return false;
-      if (current_index > &(tree->indexes[tree->reserved_size + 1]))
+      }
+      if (current_index > &(tree->indexes[tree->reserved_size + 1])) {
         return false;
-      if (current_data <= &(tree->data[0]))
+      }
+      if (current_data <= &(tree->data[0])) {
         return false;
-      if (current_data > &(tree->data[tree->reserved_size + 1]))
+      }
+      if (current_data > &(tree->data[tree->reserved_size + 1])) {
         return false;
-      if (*current_index == unused_index)
+      }
+      if (*current_index == unused_index) {
         return false;
-      if (current_index - tree->indexes != current_data - tree->data)
+      }
+      if (current_index - tree->indexes != current_data - tree->data) {
         return false;
+      }
     }
 #endif
   return true;
@@ -1267,30 +1359,39 @@ bool
 PPL::CO_Tree::iterator::OK() const {
 #if PPL_CO_TREE_EXTRA_DEBUG
   if (tree == 0) {
-    if (current_index != 0)
+    if (current_index != 0) {
       return false;
-    if (current_data != 0)
+    }
+    if (current_data != 0) {
       return false;
+    }
   }
   else
     if (tree->reserved_size == 0) {
       if (current_index != 1 + static_cast<dimension_type*>(0)
-          || current_data != 1 + static_cast<data_type*>(0))
+          || current_data != 1 + static_cast<data_type*>(0)) {
         return false;
+      }
     }
     else {
-      if (current_index <= &(tree->indexes[0]))
+      if (current_index <= &(tree->indexes[0])) {
         return false;
-      if (current_index > &(tree->indexes[tree->reserved_size + 1]))
+      }
+      if (current_index > &(tree->indexes[tree->reserved_size + 1])) {
         return false;
-      if (current_data <= &(tree->data[0]))
+      }
+      if (current_data <= &(tree->data[0])) {
         return false;
-      if (current_data > &(tree->data[tree->reserved_size + 1]))
+      }
+      if (current_data > &(tree->data[tree->reserved_size + 1])) {
         return false;
-      if (*current_index == unused_index)
+      }
+      if (*current_index == unused_index) {
         return false;
-      if (current_index - tree->indexes != current_data - tree->data)
+      }
+      if (current_index - tree->indexes != current_data - tree->data) {
         return false;
+      }
     }
 #endif
   return true;
@@ -1298,14 +1399,16 @@ PPL::CO_Tree::iterator::OK() const {
 
 bool
 PPL::CO_Tree::tree_iterator::OK() const {
-  if (i == 0 || i > tree.reserved_size)
+  if (i == 0 || i > tree.reserved_size) {
     return false;
+  }
 
   // This assumes two's complement encoding.
   const dimension_type correct_offset = i & -i;
 
-  if (offset != correct_offset)
+  if (offset != correct_offset) {
     return false;
+  }
 
   return true;
 }
@@ -1317,8 +1420,9 @@ PPL::CO_Tree::tree_iterator::go_down_searching_key(dimension_type key) {
   PPL_ASSERT(key != unused_index);
   PPL_ASSERT(index() != unused_index);
   while (!is_leaf()) {
-    if (key == index())
+    if (key == index()) {
       break;
+    }
     if (key < index()) {
       get_left_child();
       if (index() == unused_index) {
