@@ -1,6 +1,6 @@
 /* Generator_System class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2016 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -22,12 +22,12 @@ For the most up-to-date information see the Parma Polyhedra Library
 site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl-config.h"
-#include "Generator_System.defs.hh"
-#include "Generator_System.inlines.hh"
-#include "Constraint.defs.hh"
-#include "Scalar_Products.defs.hh"
-#include "Scalar_Products.inlines.hh"
-#include "assert.hh"
+#include "Generator_System_defs.hh"
+#include "Generator_System_inlines.hh"
+#include "Constraint_defs.hh"
+#include "Scalar_Products_defs.hh"
+#include "Scalar_Products_inlines.hh"
+#include "assertions.hh"
 #include <string>
 #include <vector>
 #include <iostream>
@@ -38,7 +38,7 @@ namespace PPL = Parma_Polyhedra_Library;
 bool
 PPL::Generator_System::
 adjust_topology_and_space_dimension(const Topology new_topology,
-				    const dimension_type new_space_dim) {
+                                    const dimension_type new_space_dim) {
   PPL_ASSERT(space_dimension() <= new_space_dim);
 
   if (sys.topology() != new_topology) {
@@ -47,20 +47,25 @@ adjust_topology_and_space_dimension(const Topology new_topology,
       // can be converted to a NECESSARILY_CLOSED one
       // only if it does not contain closure points.
       // This check has to be performed under the user viewpoint.
-      if (has_closure_points())
+      if (has_closure_points()) {
         return false;
+      }
       // For a correct implementation, we have to remove those
       // closure points that were matching a point (i.e., those
       // that are in the generator system, but are invisible to
       // the user).
-      Generator_System& gs = *this;
-      for (dimension_type i = 0; i < sys.num_rows(); )
-        if (gs[i].is_closure_point())
+      const Generator_System& gs = *this;
+      for (dimension_type i = 0; i < sys.num_rows(); ) {
+        if (gs[i].is_closure_point()) {
           sys.remove_row(i, false);
-        else
+        }
+        else {
           ++i;
+        }
+      }
       sys.set_necessarily_closed();
-    } else {
+    }
+    else {
       convert_into_non_necessarily_closed();
     }
   }
@@ -124,13 +129,16 @@ PPL::Generator_System::add_corresponding_points() {
 
 bool
 PPL::Generator_System::has_closure_points() const {
-  if (sys.is_necessarily_closed())
+  if (sys.is_necessarily_closed()) {
     return false;
+  }
   // Adopt the point of view of the user.
   for (Generator_System::const_iterator i = begin(),
-	 this_end = end(); i != this_end; ++i)
-    if (i->is_closure_point())
+         this_end = end(); i != this_end; ++i) {
+    if (i->is_closure_point()) {
       return true;
+    }
+  }
   return false;
 }
 
@@ -146,8 +154,9 @@ PPL::Generator_System::convert_into_non_necessarily_closed() {
 
   for (dimension_type i = sys.rows.size(); i-- > 0; ) {
     Generator& gen = sys.rows[i];
-    if (!gen.is_line_or_ray())
+    if (!gen.is_line_or_ray()) {
       gen.set_epsilon_coefficient(gen.expr.inhomogeneous_term());
+    }
   }
 
   PPL_ASSERT(sys.OK());
@@ -157,16 +166,20 @@ bool
 PPL::Generator_System::has_points() const {
   const Generator_System& gs = *this;
   // Avoiding the repeated tests on topology.
-  if (sys.is_necessarily_closed())
+  if (sys.is_necessarily_closed()) {
     for (dimension_type i = sys.num_rows(); i-- > 0; ) {
-      if (!gs[i].is_line_or_ray())
-	return true;
+      if (!gs[i].is_line_or_ray()) {
+        return true;
+      }
     }
+  }
   else {
     // !is_necessarily_closed()
-    for (dimension_type i = sys.num_rows(); i-- > 0; )
-    if (gs[i].epsilon_coefficient() != 0)
-      return true;
+    for (dimension_type i = sys.num_rows(); i-- > 0; ) {
+      if (gs[i].epsilon_coefficient() != 0) {
+        return true;
+      }
+    }
   }
   return false;
 }
@@ -181,9 +194,10 @@ PPL::Generator_System_const_iterator::skip_forward() {
       const Generator& cp = *i;
       const Generator& p = *i_next;
       if (cp.is_closure_point()
-	  && p.is_point()
-	  && cp.is_matching_closure_point(p))
-	i = i_next;
+          && p.is_point()
+          && cp.is_matching_closure_point(p)) {
+        i = i_next;
+      }
     }
   }
 }
@@ -205,9 +219,10 @@ PPL::Generator_System::insert(Generator& g, Recycle_Input) {
   // We are sure that the matrix has no pending rows
   // and that the new row is not a pending generator.
   PPL_ASSERT(sys.num_pending_rows() == 0);
-  if (sys.topology() == g.topology())
+  if (sys.topology() == g.topology()) {
     sys.insert(g, Recycle_Input());
-  else
+  }
+  else {
     // `*this' and `g' have different topologies.
     if (sys.is_necessarily_closed()) {
       convert_into_non_necessarily_closed();
@@ -225,19 +240,22 @@ PPL::Generator_System::insert(Generator& g, Recycle_Input) {
       // If it was a point, set the epsilon coordinate to 1
       // (i.e., set the coefficient equal to the divisor).
       // Note: normalization is preserved.
-      if (!g.is_line_or_ray())
-	g.set_epsilon_coefficient(g.expr.inhomogeneous_term());
+      if (!g.is_line_or_ray()) {
+        g.set_epsilon_coefficient(g.expr.inhomogeneous_term());
+      }
       // Inserting the new generator.
       sys.insert(g, Recycle_Input());
     }
+  }
   PPL_ASSERT(OK());
 }
 
 void
 PPL::Generator_System::insert_pending(Generator& g, Recycle_Input) {
-  if (sys.topology() == g.topology())
+  if (sys.topology() == g.topology()) {
     sys.insert_pending(g, Recycle_Input());
-  else
+  }
+  else {
     // `*this' and `g' have different topologies.
     if (sys.is_necessarily_closed()) {
       convert_into_non_necessarily_closed();
@@ -256,11 +274,13 @@ PPL::Generator_System::insert_pending(Generator& g, Recycle_Input) {
       // If it was a point, set the epsilon coordinate to 1
       // (i.e., set the coefficient equal to the divisor).
       // Note: normalization is preserved.
-      if (!g.is_line_or_ray())
-	g.set_epsilon_coefficient(g.expr.inhomogeneous_term());
+      if (!g.is_line_or_ray()) {
+        g.set_epsilon_coefficient(g.expr.inhomogeneous_term());
+      }
       // Inserting the new generator.
       sys.insert_pending(g, Recycle_Input());
     }
+  }
   PPL_ASSERT(OK());
 }
 
@@ -274,14 +294,18 @@ PPL::Generator_System::num_lines() const {
   // If sys happens to be sorted, take advantage of the fact
   // that lines are at the top of the system.
   if (sys.is_sorted()) {
-    dimension_type nrows = sys.num_rows();
-    for (dimension_type i = 0; i < nrows && gs[i].is_line(); ++i)
+    const dimension_type nrows = sys.num_rows();
+    for (dimension_type i = 0; i < nrows && gs[i].is_line(); ++i) {
       ++n;
+    }
+  }
+  else {
+    for (dimension_type i = sys.num_rows(); i-- > 0 ; ) {
+      if (gs[i].is_line()) {
+        ++n;
+      }
+    }
   }
-  else
-    for (dimension_type i = sys.num_rows(); i-- > 0 ; )
-      if (gs[i].is_line())
-	++n;
   return n;
 }
 
@@ -296,14 +320,20 @@ PPL::Generator_System::num_rays() const {
   // that rays and points are at the bottom of the system and
   // rays have the inhomogeneous term equal to zero.
   if (sys.is_sorted()) {
-    for (dimension_type i = sys.num_rows(); i != 0 && gs[--i].is_ray_or_point(); )
-      if (gs[i].is_line_or_ray())
-	++n;
+    for (dimension_type i = sys.num_rows();
+         i != 0 && gs[--i].is_ray_or_point(); ) {
+      if (gs[i].is_line_or_ray()) {
+        ++n;
+      }
+    }
+  }
+  else {
+    for (dimension_type i = sys.num_rows(); i-- > 0 ; ) {
+      if (gs[i].is_ray()) {
+        ++n;
+      }
+    }
   }
-  else
-    for (dimension_type i = sys.num_rows(); i-- > 0 ; )
-      if (gs[i].is_ray())
-	++n;
   return n;
 }
 
@@ -337,62 +367,68 @@ PPL::Generator_System::relation_with(const Constraint& c) const {
       int first_point_or_nonsaturating_ray_sign = 2;
 
       for (dimension_type i = n_rows; i-- > 0; ) {
-	const Generator& g = gs[i];
-	const int sp_sign = Scalar_Products::sign(c, g);
-	// Checking whether the generator saturates the equality.
-	// If that is the case, then we have to do something only if
-	// the generator is a point.
-	if (sp_sign == 0) {
-	  if (g.is_point()) {
-	    if (first_point_or_nonsaturating_ray_sign == 2)
-	      // It is the first time that we find a point and
-	      // we have not found a non-saturating ray yet.
-	      first_point_or_nonsaturating_ray_sign = 0;
-	    else
-	      // We already found a point or a non-saturating ray.
-	      if (first_point_or_nonsaturating_ray_sign != 0)
-		return Poly_Con_Relation::strictly_intersects();
-	  }
-	}
-	else
-	  // Here we know that sp_sign != 0.
-	  switch (g.type()) {
+        const Generator& g = gs[i];
+        const int sp_sign = Scalar_Products::sign(c, g);
+        // Checking whether the generator saturates the equality.
+        // If that is the case, then we have to do something only if
+        // the generator is a point.
+        if (sp_sign == 0) {
+          if (g.is_point()) {
+            if (first_point_or_nonsaturating_ray_sign == 2) {
+              // It is the first time that we find a point and
+              // we have not found a non-saturating ray yet.
+              first_point_or_nonsaturating_ray_sign = 0;
+            }
+            else {
+              // We already found a point or a non-saturating ray.
+              if (first_point_or_nonsaturating_ray_sign != 0) {
+                return Poly_Con_Relation::strictly_intersects();
+              }
+            }
+          }
+        }
+        else {
+          // Here we know that sp_sign != 0.
+          switch (g.type()) {
 
-	  case Generator::LINE:
-	    // If a line does not saturate `c', then there is a strict
-	    // intersection between the points satisfying `c'
-	    // and the points generated by `gs'.
-	    return Poly_Con_Relation::strictly_intersects();
+          case Generator::LINE:
+            // If a line does not saturate `c', then there is a strict
+            // intersection between the points satisfying `c'
+            // and the points generated by `gs'.
+            return Poly_Con_Relation::strictly_intersects();
 
-	  case Generator::RAY:
-	    if (first_point_or_nonsaturating_ray_sign == 2) {
-	      // It is the first time that we have a non-saturating ray
-	      // and we have not found any point yet.
-	      first_point_or_nonsaturating_ray_sign = sp_sign;
-	      result = Poly_Con_Relation::is_disjoint();
-	    }
-	    else
-	      // We already found a point or a non-saturating ray.
-	      if (sp_sign != first_point_or_nonsaturating_ray_sign)
-		return Poly_Con_Relation::strictly_intersects();
-	    break;
+          case Generator::RAY:
+            if (first_point_or_nonsaturating_ray_sign == 2) {
+              // It is the first time that we have a non-saturating ray
+              // and we have not found any point yet.
+              first_point_or_nonsaturating_ray_sign = sp_sign;
+              result = Poly_Con_Relation::is_disjoint();
+            }
+            else
+              // We already found a point or a non-saturating ray.
+              if (sp_sign != first_point_or_nonsaturating_ray_sign) {
+                return Poly_Con_Relation::strictly_intersects();
+              }
+            break;
 
-	  case Generator::POINT:
-	  case Generator::CLOSURE_POINT:
-	    // NOTE: a non-saturating closure point is treated as
-	    // a normal point.
-	    if (first_point_or_nonsaturating_ray_sign == 2) {
-	      // It is the first time that we find a point and
-	      // we have not found a non-saturating ray yet.
-	      first_point_or_nonsaturating_ray_sign = sp_sign;
-	      result = Poly_Con_Relation::is_disjoint();
-	    }
-	    else
-	      // We already found a point or a non-saturating ray.
-	      if (sp_sign != first_point_or_nonsaturating_ray_sign)
-		return Poly_Con_Relation::strictly_intersects();
-	    break;
-	  }
+          case Generator::POINT:
+          case Generator::CLOSURE_POINT:
+            // NOTE: a non-saturating closure point is treated as
+            // a normal point.
+            if (first_point_or_nonsaturating_ray_sign == 2) {
+              // It is the first time that we find a point and
+              // we have not found a non-saturating ray yet.
+              first_point_or_nonsaturating_ray_sign = sp_sign;
+              result = Poly_Con_Relation::is_disjoint();
+            }
+            else
+              // We already found a point or a non-saturating ray.
+              if (sp_sign != first_point_or_nonsaturating_ray_sign) {
+                return Poly_Con_Relation::strictly_intersects();
+              }
+            break;
+          }
+        }
       }
     }
     break;
@@ -408,103 +444,113 @@ PPL::Generator_System::relation_with(const Constraint& c) const {
       bool first_point_or_nonsaturating_ray = true;
 
       for (dimension_type i = n_rows; i-- > 0; ) {
-	const Generator& g = gs[i];
-	const int sp_sign = Scalar_Products::sign(c, g);
-	// Checking whether the generator saturates the non-strict
-	// inequality. If that is the case, then we have to do something
-	// only if the generator is a point.
-	if (sp_sign == 0) {
-	  if (g.is_point()) {
-	    if (first_point_or_nonsaturating_ray)
-	      // It is the first time that we have a point and
-	      // we have not found a non-saturating ray yet.
-	      first_point_or_nonsaturating_ray = false;
-	    else
-	      // We already found a point or a non-saturating ray before.
-	      if (result == Poly_Con_Relation::is_disjoint())
-		// Since g saturates c, we have a strict intersection if
-		// none of the generators seen so far are included in `c'.
-		return Poly_Con_Relation::strictly_intersects();
-	  }
-	}
-	else
-	  // Here we know that sp_sign != 0.
-	  switch (g.type()) {
+        const Generator& g = gs[i];
+        const int sp_sign = Scalar_Products::sign(c, g);
+        // Checking whether the generator saturates the non-strict
+        // inequality. If that is the case, then we have to do something
+        // only if the generator is a point.
+        if (sp_sign == 0) {
+          if (g.is_point()) {
+            if (first_point_or_nonsaturating_ray) {
+              // It is the first time that we have a point and
+              // we have not found a non-saturating ray yet.
+              first_point_or_nonsaturating_ray = false;
+            }
+            else {
+              // We already found a point or a non-saturating ray before.
+              if (result == Poly_Con_Relation::is_disjoint()) {
+                // Since g saturates c, we have a strict intersection if
+                // none of the generators seen so far are included in `c'.
+                return Poly_Con_Relation::strictly_intersects();
+              }
+            }
+          }
+        }
+        else {
+          // Here we know that sp_sign != 0.
+          switch (g.type()) {
 
-	  case Generator::LINE:
-	    // If a line does not saturate `c', then there is a strict
-	    // intersection between the points satisfying `c' and
-	    // the points generated by `gs'.
-	    return Poly_Con_Relation::strictly_intersects();
+          case Generator::LINE:
+            // If a line does not saturate `c', then there is a strict
+            // intersection between the points satisfying `c' and
+            // the points generated by `gs'.
+            return Poly_Con_Relation::strictly_intersects();
 
-	  case Generator::RAY:
-	    if (first_point_or_nonsaturating_ray) {
-	      // It is the first time that we have a non-saturating ray
-	      // and we have not found any point yet.
-	      first_point_or_nonsaturating_ray = false;
-	      result = (sp_sign > 0)
-		? Poly_Con_Relation::is_included()
-		: Poly_Con_Relation::is_disjoint();
-	    }
-	    else {
-	      // We already found a point or a non-saturating ray.
-	      if ((sp_sign > 0
-		   && result == Poly_Con_Relation::is_disjoint())
-		  || (sp_sign < 0
-		      && result.implies(Poly_Con_Relation::is_included())))
-		// We have a strict intersection if either:
-		// - `g' satisfies `c' but none of the generators seen
-		//    so far are included in `c'; or
-		// - `g' does not satisfy `c' and all the generators
-		//    seen so far are included in `c'.
-		return Poly_Con_Relation::strictly_intersects();
-	      if (sp_sign > 0)
-		// Here all the generators seen so far either saturate
-		// or are included in `c'.
-		// Since `g' does not saturate `c' ...
-		result = Poly_Con_Relation::is_included();
-	    }
-	    break;
+          case Generator::RAY:
+            if (first_point_or_nonsaturating_ray) {
+              // It is the first time that we have a non-saturating ray
+              // and we have not found any point yet.
+              first_point_or_nonsaturating_ray = false;
+              result = (sp_sign > 0)
+                ? Poly_Con_Relation::is_included()
+                : Poly_Con_Relation::is_disjoint();
+            }
+            else {
+              // We already found a point or a non-saturating ray.
+              if ((sp_sign > 0
+                   && result == Poly_Con_Relation::is_disjoint())
+                  || (sp_sign < 0
+                      && result.implies(Poly_Con_Relation::is_included()))) {
+                // We have a strict intersection if either:
+                // - `g' satisfies `c' but none of the generators seen
+                //    so far are included in `c'; or
+                // - `g' does not satisfy `c' and all the generators
+                //    seen so far are included in `c'.
+                return Poly_Con_Relation::strictly_intersects();
+              }
+              if (sp_sign > 0) {
+                // Here all the generators seen so far either saturate
+                // or are included in `c'.
+                // Since `g' does not saturate `c' ...
+                result = Poly_Con_Relation::is_included();
+              }
+            }
+            break;
 
-	  case Generator::POINT:
-	  case Generator::CLOSURE_POINT:
-	    // NOTE: a non-saturating closure point is treated as
-	    // a normal point.
-	    if (first_point_or_nonsaturating_ray) {
-	      // It is the first time that we have a point and
-	      // we have not found a non-saturating ray yet.
-	      // - If point `g' saturates `c', then all the generators
-	      //   seen so far saturate `c'.
-	      // - If point `g' is included (but does not saturate) `c',
-	      //   then all the generators seen so far are included in `c'.
-	      // - If point `g' does not satisfy `c', then all the
-	      //   generators seen so far are disjoint from `c'.
-	      first_point_or_nonsaturating_ray = false;
-	      if (sp_sign > 0)
-		result = Poly_Con_Relation::is_included();
-	      else if (sp_sign < 0)
-		result = Poly_Con_Relation::is_disjoint();
-	    }
-	    else {
-	      // We already found a point or a non-saturating ray before.
-	      if ((sp_sign > 0
-		   && result == Poly_Con_Relation::is_disjoint())
-		  || (sp_sign < 0
-		      && result.implies(Poly_Con_Relation::is_included())))
-		// We have a strict intersection if either:
-		// - `g' satisfies or saturates `c' but none of the
-		//    generators seen so far are included in `c'; or
-		// - `g' does not satisfy `c' and all the generators
-		//    seen so far are included in `c'.
-		return Poly_Con_Relation::strictly_intersects();
-	      if (sp_sign > 0)
-		// Here all the generators seen so far either saturate
-		// or are included in `c'.
-		// Since `g' does not saturate `c' ...
-		result = Poly_Con_Relation::is_included();
-	    }
-	    break;
-	  }
+          case Generator::POINT:
+          case Generator::CLOSURE_POINT:
+            // NOTE: a non-saturating closure point is treated as
+            // a normal point.
+            if (first_point_or_nonsaturating_ray) {
+              // It is the first time that we have a point and
+              // we have not found a non-saturating ray yet.
+              // - If point `g' saturates `c', then all the generators
+              //   seen so far saturate `c'.
+              // - If point `g' is included (but does not saturate) `c',
+              //   then all the generators seen so far are included in `c'.
+              // - If point `g' does not satisfy `c', then all the
+              //   generators seen so far are disjoint from `c'.
+              first_point_or_nonsaturating_ray = false;
+              if (sp_sign > 0) {
+                result = Poly_Con_Relation::is_included();
+              }
+              else if (sp_sign < 0) {
+                result = Poly_Con_Relation::is_disjoint();
+              }
+            }
+            else {
+              // We already found a point or a non-saturating ray before.
+              if ((sp_sign > 0
+                   && result == Poly_Con_Relation::is_disjoint())
+                  || (sp_sign < 0
+                      && result.implies(Poly_Con_Relation::is_included()))) {
+                // We have a strict intersection if either:
+                // - `g' satisfies or saturates `c' but none of the
+                //    generators seen so far are included in `c'; or
+                // - `g' does not satisfy `c' and all the generators
+                //    seen so far are included in `c'.
+                return Poly_Con_Relation::strictly_intersects();
+              }
+              if (sp_sign > 0) {
+                // Here all the generators seen so far either saturate
+                // or are included in `c'.
+                // Since `g' does not saturate `c' ...
+                result = Poly_Con_Relation::is_included();
+              }
+            }
+            break;
+          }
+        }
       }
     }
     break;
@@ -519,93 +565,103 @@ PPL::Generator_System::relation_with(const Constraint& c) const {
       // non-saturating ray.
       bool first_point_or_nonsaturating_ray = true;
       for (dimension_type i = n_rows; i-- > 0; ) {
-	const Generator& g = gs[i];
-	// Using the reduced scalar product operator to avoid
-	// both topology and space dimension mismatches.
-	const int sp_sign = Scalar_Products::reduced_sign(c, g);
-	// Checking whether the generator saturates the strict inequality.
-	// If that is the case, then we have to do something
-	// only if the generator is a point.
-	if (sp_sign == 0) {
-	  if (g.is_point()) {
-	    if (first_point_or_nonsaturating_ray)
-	      // It is the first time that we have a point and
-	      // we have not found a non-saturating ray yet.
-	      first_point_or_nonsaturating_ray = false;
-	    else
-	      // We already found a point or a non-saturating ray before.
-	      if (result == Poly_Con_Relation::is_included())
-		return Poly_Con_Relation::strictly_intersects();
-	  }
-	}
-	else
-	  // Here we know that sp_sign != 0.
-	  switch (g.type()) {
+        const Generator& g = gs[i];
+        // Using the reduced scalar product operator to avoid
+        // both topology and space dimension mismatches.
+        const int sp_sign = Scalar_Products::reduced_sign(c, g);
+        // Checking whether the generator saturates the strict inequality.
+        // If that is the case, then we have to do something
+        // only if the generator is a point.
+        if (sp_sign == 0) {
+          if (g.is_point()) {
+            if (first_point_or_nonsaturating_ray) {
+              // It is the first time that we have a point and
+              // we have not found a non-saturating ray yet.
+              first_point_or_nonsaturating_ray = false;
+            }
+            else {
+              // We already found a point or a non-saturating ray before.
+              if (result == Poly_Con_Relation::is_included()) {
+                return Poly_Con_Relation::strictly_intersects();
+              }
+            }
+          }
+        }
+        else {
+          // Here we know that sp_sign != 0.
+          switch (g.type()) {
 
-	  case Generator::LINE:
-	    // If a line does not saturate `c', then there is a strict
-	    // intersection between the points satisfying `c' and the points
-	    // generated by `gs'.
-	    return Poly_Con_Relation::strictly_intersects();
+          case Generator::LINE:
+            // If a line does not saturate `c', then there is a strict
+            // intersection between the points satisfying `c' and the points
+            // generated by `gs'.
+            return Poly_Con_Relation::strictly_intersects();
 
-	  case Generator::RAY:
-	    if (first_point_or_nonsaturating_ray) {
-	      // It is the first time that we have a non-saturating ray
-	      // and we have not found any point yet.
-	      first_point_or_nonsaturating_ray = false;
-	      result = (sp_sign > 0)
-		? Poly_Con_Relation::is_included()
-		: Poly_Con_Relation::is_disjoint();
-	    }
-	    else {
-	      // We already found a point or a non-saturating ray before.
-	      if ((sp_sign > 0
-		   && result.implies(Poly_Con_Relation::is_disjoint()))
-		  ||
-		  (sp_sign <= 0
-		   && result == Poly_Con_Relation::is_included()))
-		return Poly_Con_Relation::strictly_intersects();
-	      if (sp_sign < 0)
-		// Here all the generators seen so far either saturate
-		// or are disjoint from `c'.
-		// Since `g' does not saturate `c' ...
-		result = Poly_Con_Relation::is_disjoint();
-	    }
-	    break;
+          case Generator::RAY:
+            if (first_point_or_nonsaturating_ray) {
+              // It is the first time that we have a non-saturating ray
+              // and we have not found any point yet.
+              first_point_or_nonsaturating_ray = false;
+              result = (sp_sign > 0)
+                ? Poly_Con_Relation::is_included()
+                : Poly_Con_Relation::is_disjoint();
+            }
+            else {
+              // We already found a point or a non-saturating ray before.
+              if ((sp_sign > 0
+                   && result.implies(Poly_Con_Relation::is_disjoint()))
+                  ||
+                  (sp_sign <= 0
+                   && result == Poly_Con_Relation::is_included())) {
+                return Poly_Con_Relation::strictly_intersects();
+              }
+              if (sp_sign < 0) {
+                // Here all the generators seen so far either saturate
+                // or are disjoint from `c'.
+                // Since `g' does not saturate `c' ...
+                result = Poly_Con_Relation::is_disjoint();
+              }
+            }
+            break;
 
-	  case Generator::POINT:
-	  case Generator::CLOSURE_POINT:
-	    if (first_point_or_nonsaturating_ray) {
-	      // It is the first time that we have a point and
-	      // we have not found a non-saturating ray yet.
-	      // - If point `g' saturates `c', then all the generators
-	      //   seen so far saturate `c'.
-	      // - If point `g' is included in (but does not saturate) `c',
-	      //   then all the generators seen so far are included in `c'.
-	      // - If point `g' strictly violates `c', then all the
-	      //   generators seen so far are disjoint from `c'.
-	      first_point_or_nonsaturating_ray = false;
-	      if (sp_sign > 0)
-		result = Poly_Con_Relation::is_included();
-	      else if (sp_sign < 0)
-		result = Poly_Con_Relation::is_disjoint();
-	    }
-	    else {
-	      // We already found a point or a non-saturating ray before.
-	      if ((sp_sign > 0
-		   && result.implies(Poly_Con_Relation::is_disjoint()))
-		  ||
-		  (sp_sign <= 0
-		   && result == Poly_Con_Relation::is_included()))
-		return Poly_Con_Relation::strictly_intersects();
-	      if (sp_sign < 0)
-		// Here all the generators seen so far either saturate
-		// or are disjoint from `c'.
-		// Since `g' does not saturate `c' ...
-		result = Poly_Con_Relation::is_disjoint();
-	    }
-	    break;
-	  }
+          case Generator::POINT:
+          case Generator::CLOSURE_POINT:
+            if (first_point_or_nonsaturating_ray) {
+              // It is the first time that we have a point and
+              // we have not found a non-saturating ray yet.
+              // - If point `g' saturates `c', then all the generators
+              //   seen so far saturate `c'.
+              // - If point `g' is included in (but does not saturate) `c',
+              //   then all the generators seen so far are included in `c'.
+              // - If point `g' strictly violates `c', then all the
+              //   generators seen so far are disjoint from `c'.
+              first_point_or_nonsaturating_ray = false;
+              if (sp_sign > 0) {
+                result = Poly_Con_Relation::is_included();
+              }
+              else if (sp_sign < 0) {
+                result = Poly_Con_Relation::is_disjoint();
+              }
+            }
+            else {
+              // We already found a point or a non-saturating ray before.
+              if ((sp_sign > 0
+                   && result.implies(Poly_Con_Relation::is_disjoint()))
+                  ||
+                  (sp_sign <= 0
+                   && result == Poly_Con_Relation::is_included())) {
+                return Poly_Con_Relation::strictly_intersects();
+              }
+              if (sp_sign < 0) {
+                // Here all the generators seen so far either saturate
+                // or are disjoint from `c'.
+                // Since `g' does not saturate `c' ...
+                result = Poly_Con_Relation::is_disjoint();
+              }
+            }
+            break;
+          }
+        }
       }
     }
     break;
@@ -622,15 +678,17 @@ PPL::Generator_System::satisfied_by_all_generators(const Constraint& c) const {
   // Setting `sps' to the appropriate scalar product sign operator.
   // This also avoids problems when having _legal_ topology mismatches
   // (which could also cause a mismatch in the number of space dimensions).
-  Topology_Adjusted_Scalar_Product_Sign sps(c);
+  const Topology_Adjusted_Scalar_Product_Sign sps(c);
 
   const Generator_System& gs = *this;
   switch (c.type()) {
   case Constraint::EQUALITY:
     // Equalities must be saturated by all generators.
-    for (dimension_type i = gs.sys.num_rows(); i-- > 0; )
-      if (sps(c, gs[i]) != 0)
-	return false;
+    for (dimension_type i = gs.sys.num_rows(); i-- > 0; ) {
+      if (sps(c, gs[i]) != 0) {
+        return false;
+      }
+    }
     break;
   case Constraint::NONSTRICT_INEQUALITY:
     // Non-strict inequalities must be saturated by lines and
@@ -639,13 +697,15 @@ PPL::Generator_System::satisfied_by_all_generators(const Constraint& c) const {
       const Generator& g = gs[i];
       const int sp_sign = sps(c, g);
       if (g.is_line()) {
-	if (sp_sign != 0)
-	  return false;
+        if (sp_sign != 0) {
+          return false;
+        }
       }
       else
-	// `g' is a ray, point or closure point.
-	if (sp_sign < 0)
-	  return false;
+        // `g' is a ray, point or closure point.
+        if (sp_sign < 0) {
+          return false;
+        }
     }
     break;
   case Constraint::STRICT_INEQUALITY:
@@ -656,18 +716,21 @@ PPL::Generator_System::satisfied_by_all_generators(const Constraint& c) const {
       const int sp_sign = sps(c, g);
       switch (g.type()) {
       case Generator::POINT:
-	if (sp_sign <= 0)
-	  return false;
-	break;
+        if (sp_sign <= 0) {
+          return false;
+        }
+        break;
       case Generator::LINE:
-	if (sp_sign != 0)
-	  return false;
-	break;
+        if (sp_sign != 0) {
+          return false;
+        }
+        break;
       default:
-	// `g' is a ray or closure point.
-	if (sp_sign < 0)
-	  return false;
-	break;
+        // `g' is a ray or closure point.
+        if (sp_sign < 0) {
+          return false;
+        }
+        break;
       }
     }
     break;
@@ -680,8 +743,8 @@ PPL::Generator_System::satisfied_by_all_generators(const Constraint& c) const {
 void
 PPL::Generator_System
 ::affine_image(Variable v,
-	       const Linear_Expression& expr,
-	       Coefficient_traits::const_reference denominator) {
+               const Linear_Expression& expr,
+               Coefficient_traits::const_reference denominator) {
   Generator_System& x = *this;
   PPL_ASSERT(v.space_dimension() <= x.space_dimension());
   PPL_ASSERT(expr.space_dimension() <= x.space_dimension());
@@ -712,8 +775,9 @@ PPL::Generator_System
   // valid lines and rays into the origin of the space.
   const bool not_invertible = (v.space_dimension() > expr.space_dimension()
                                || expr.coefficient(v) == 0);
-  if (not_invertible)
+  if (not_invertible) {
     x.remove_invalid_lines_and_rays();
+  }
 
   // TODO: Consider normalizing individual rows in the loop above.
   // Strong normalization also resets the sortedness flag.
@@ -722,8 +786,9 @@ PPL::Generator_System
 #ifndef NDEBUG
   // Make sure that the (remaining) generators are still OK after fiddling
   // with their internal data.
-  for (dimension_type i = x.num_rows(); i-- > 0; )
+  for (dimension_type i = x.num_rows(); i-- > 0; ) {
     PPL_ASSERT(x.sys[i].OK());
+  }
 #endif
 
   PPL_ASSERT(sys.OK());
@@ -738,8 +803,9 @@ PPL_OUTPUT_DEFINITIONS(Generator_System)
 
 bool
 PPL::Generator_System::ascii_load(std::istream& s) {
-  if (!sys.ascii_load(s))
+  if (!sys.ascii_load(s)) {
     return false;
+  }
 
   PPL_ASSERT(OK());
   return true;
@@ -751,7 +817,7 @@ PPL::Generator_System::remove_invalid_lines_and_rays() {
   // NOTE: the following swaps will mix generators without even trying
   // to preserve sortedness: as a matter of fact, it will almost always
   // be the case that the input generator system is NOT sorted.
-  
+
   // Note that num_rows() is *not* constant, because it is decreased by
   // remove_row().
   for (dimension_type i = 0; i < num_rows(); ) {
@@ -759,8 +825,10 @@ PPL::Generator_System::remove_invalid_lines_and_rays() {
     if (g.is_line_or_ray() && g.expr.all_homogeneous_terms_are_zero()) {
       sys.remove_row(i, false);
       set_sorted(false);
-    } else
+    }
+    else {
       ++i;
+    }
   }
 }
 
@@ -790,14 +858,15 @@ std::ostream&
 PPL::IO_Operators::operator<<(std::ostream& s, const Generator_System& gs) {
   Generator_System::const_iterator i = gs.begin();
   const Generator_System::const_iterator gs_end = gs.end();
-  if (i == gs_end)
+  if (i == gs_end) {
     return s << "false";
+  }
   while (true) {
     s << *i;
     ++i;
-    if (i == gs_end)
+    if (i == gs_end) {
       return s;
+    }
     s << ", ";
   }
 }
-
