@@ -1,6 +1,6 @@
 /* Grid class implementation: simplify().
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2016 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -22,7 +22,7 @@ For the most up-to-date information see the Parma Polyhedra Library
 site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl-config.h"
-#include "assert.hh"
+#include "assertions.hh"
 #include "Grid_defs.hh"
 
 namespace Parma_Polyhedra_Library {
@@ -172,9 +172,10 @@ Grid::reduce_parameter_with_line(Grid_Generator& row,
   // all other parameters to match.
   for (dimension_type index = rows.size(); index-- > 0; ) {
     Grid_Generator& gen = rows[index];
-    if (gen.is_parameter_or_point())
+    if (gen.is_parameter_or_point()) {
       // Do not scale the last coefficient.
       gen.expr.mul_assign(reduced_pivot_col, 0, num_columns);
+    }
   }
 
   // Subtract from row a multiple of pivot such that the result in
@@ -222,8 +223,9 @@ Grid::reduce_congruence_with_equality(Congruence& row,
   // other proper congruences in the same way.
   for (dimension_type index = sys.size(); index-- > 0; ) {
     Congruence& cg = sys[index];
-    if (cg.is_proper_congruence())
+    if (cg.is_proper_congruence()) {
       cg.scale(reduced_pivot_col);
+    }
   }
   // Subtract from row a multiple of pivot such that the result in
   // row[column] is zero.
@@ -238,8 +240,9 @@ Grid::rows_are_zero(M& system, dimension_type first,
                     dimension_type last, dimension_type row_size) {
   while (first <= last) {
     const R& row = system[first++];
-    if (!row.expr.all_zeroes(0, row_size))
+    if (!row.expr.all_zeroes(0, row_size)) {
       return false;
+    }
   }
   return true;
 }
@@ -253,8 +256,9 @@ Grid::simplify(Grid_Generator_System& ggs, Dimension_Kinds& dim_kinds) {
   // Subtract one to allow for the parameter divisor column
   const dimension_type num_columns = ggs.space_dimension() + 1;
 
-  if (dim_kinds.size() != num_columns)
+  if (dim_kinds.size() != num_columns) {
     dim_kinds.resize(num_columns);
+  }
 
   const dimension_type num_rows = ggs.num_rows();
 
@@ -269,12 +273,14 @@ Grid::simplify(Grid_Generator_System& ggs, Dimension_Kinds& dim_kinds) {
 
     // Move down over rows which have zero in column `dim'.
     while (row_index < num_rows
-           && ggs.sys.rows[row_index].expr.get(dim) == 0)
+           && ggs.sys.rows[row_index].expr.get(dim) == 0) {
       ++row_index;
+    }
 
-    if (row_index == num_rows)
+    if (row_index == num_rows) {
       // Element in column `dim' is zero in all rows from the pivot.
       dim_kinds[dim] = GEN_VIRTUAL;
+    }
     else {
       if (row_index != pivot_index) {
         using std::swap;
@@ -289,12 +295,14 @@ Grid::simplify(Grid_Generator_System& ggs, Dimension_Kinds& dim_kinds) {
         ++row_index;
         Grid_Generator& row = ggs.sys.rows[row_index];
 
-        if (row.expr.get(dim) == 0)
+        if (row.expr.get(dim) == 0) {
           continue;
+        }
 
-        if (row.is_line())
-          if (pivot_is_line)
+        if (row.is_line()) {
+          if (pivot_is_line) {
             reduce_line_with_line(row, pivot, dim);
+          }
           else {
             PPL_ASSERT(pivot.is_parameter_or_point());
             using std::swap;
@@ -303,11 +311,13 @@ Grid::simplify(Grid_Generator_System& ggs, Dimension_Kinds& dim_kinds) {
             reduce_parameter_with_line(row, pivot, dim, ggs.sys.rows,
                                        num_columns + 1);
           }
+        }
         else {
           PPL_ASSERT(row.is_parameter_or_point());
-          if (pivot_is_line)
+          if (pivot_is_line) {
             reduce_parameter_with_line(row, pivot, dim, ggs.sys.rows,
                                        num_columns + 1);
+          }
           else {
             PPL_ASSERT(pivot.is_parameter_or_point());
             reduce_pc_with_pc(row, pivot, dim, dim, num_columns);
@@ -315,8 +325,9 @@ Grid::simplify(Grid_Generator_System& ggs, Dimension_Kinds& dim_kinds) {
         }
       }
 
-      if (pivot_is_line)
+      if (pivot_is_line) {
         dim_kinds[dim] = LINE;
+      }
       else {
         PPL_ASSERT(pivot.is_parameter_or_point());
         dim_kinds[dim] = PARAMETER;
@@ -324,8 +335,9 @@ Grid::simplify(Grid_Generator_System& ggs, Dimension_Kinds& dim_kinds) {
 
       // Since we are reducing the system to "strong minimal form",
       // ensure that a positive value follows the leading zeros.
-      if (pivot.expr.get(dim) < 0)
+      if (pivot.expr.get(dim) < 0) {
         pivot.expr.negate(dim, num_columns);
+      }
 
       // Factor this row out of the preceding rows.
       reduce_reduced<Grid_Generator_System>
@@ -385,8 +397,9 @@ Grid::simplify(Congruence_System& cgs, Dimension_Kinds& dim_kinds) {
   // NOTE: add one for the inhomogeneous term (but not the modulus).
   const dimension_type num_columns = cgs.space_dimension() + 1;
 
-  if (dim_kinds.size() != num_columns)
+  if (dim_kinds.size() != num_columns) {
     dim_kinds.resize(num_columns);
+  }
 
   const dimension_type num_rows = cgs.num_rows();
 
@@ -400,13 +413,15 @@ Grid::simplify(Congruence_System& cgs, Dimension_Kinds& dim_kinds) {
     dimension_type row_index = pivot_index;
 
     // Move down over rows which have zero in column `dim'.
-    while (row_index < num_rows && cgs.rows[row_index].expr.get(dim) == 0)
+    while (row_index < num_rows && cgs.rows[row_index].expr.get(dim) == 0) {
       ++row_index;
+    }
 
-    if (row_index == num_rows)
+    if (row_index == num_rows) {
       // Element in column `dim' is zero in all rows from the pivot,
       // or `cgs' is empty of rows.
       dim_kinds[dim] = CON_VIRTUAL;
+    }
     else {
       // Here row_index != num_rows.
       if (row_index != pivot_index) {
@@ -422,12 +437,14 @@ Grid::simplify(Congruence_System& cgs, Dimension_Kinds& dim_kinds) {
       while (row_index < num_rows - 1) {
         ++row_index;
         Congruence& row = cgs.rows[row_index];
-        if (row.expr.get(dim) == 0)
+        if (row.expr.get(dim) == 0) {
           continue;
+        }
 
         if (row.is_equality()) {
-          if (pivot_is_equality)
+          if (pivot_is_equality) {
             reduce_equality_with_equality(row, pivot, dim);
+          }
           else {
             PPL_ASSERT(pivot.is_proper_congruence());
             using std::swap;
@@ -438,8 +455,9 @@ Grid::simplify(Congruence_System& cgs, Dimension_Kinds& dim_kinds) {
         }
         else {
           PPL_ASSERT(row.is_proper_congruence());
-          if (pivot_is_equality)
+          if (pivot_is_equality) {
             reduce_congruence_with_equality(row, pivot, dim, cgs.rows);
+          }
           else {
             PPL_ASSERT(pivot.is_proper_congruence());
             reduce_pc_with_pc(row, pivot, dim, 0, dim + 1);
@@ -447,8 +465,9 @@ Grid::simplify(Congruence_System& cgs, Dimension_Kinds& dim_kinds) {
         }
       }
 
-      if (pivot_is_equality)
+      if (pivot_is_equality) {
         dim_kinds[dim] = EQUALITY;
+      }
       else {
         PPL_ASSERT(pivot.is_proper_congruence());
         dim_kinds[dim] = PROPER_CONGRUENCE;
@@ -456,8 +475,9 @@ Grid::simplify(Congruence_System& cgs, Dimension_Kinds& dim_kinds) {
 
       // Since we are reducing the system to "strong minimal form",
       // ensure that a positive value follows the leading zeros.
-      if (pivot.expr.get(dim) < 0)
+      if (pivot.expr.get(dim) < 0) {
         pivot.expr.negate(0, dim + 1);
+      }
 
       // Factor this row out of the preceding ones.
       reduce_reduced<Congruence_System>
@@ -493,8 +513,9 @@ Grid::simplify(Congruence_System& cgs, Dimension_Kinds& dim_kinds) {
     switch (dim_kinds[0]) {
 
     case PROPER_CONGRUENCE:
-      if (last_row.inhomogeneous_term() % last_row.modulus() == 0)
+      if (last_row.inhomogeneous_term() % last_row.modulus() == 0) {
         break;
+      }
       // The last row is a false proper congruence.
       last_row.set_modulus(Coefficient_zero());
       dim_kinds[0] = EQUALITY;
