@@ -1,6 +1,6 @@
 /* PIP_Problem class implementation: non-inline functions.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2016 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -22,8 +22,8 @@ For the most up-to-date information see the Parma Polyhedra Library
 site: http://bugseng.com/products/ppl/ . */
 
 #include "ppl-config.h"
-#include "PIP_Problem.defs.hh"
-#include "PIP_Tree.defs.hh"
+#include "PIP_Problem_defs.hh"
+#include "PIP_Tree_defs.hh"
 
 namespace PPL = Parma_Polyhedra_Library;
 
@@ -33,13 +33,16 @@ PPL::IO_Operators::operator<<(std::ostream& s, const PIP_Problem& pip) {
   s << "Space dimension: " << pip.space_dimension();
   s << "\nConstraints:";
   for (PIP_Problem::const_iterator i = pip.constraints_begin(),
-	 i_end = pip.constraints_end(); i != i_end; ++i)
+         i_end = pip.constraints_end(); i != i_end; ++i) {
     s << "\n" << *i;
+  }
   s << "\nProblem parameters: " << pip.parameter_space_dimensions();
-  if (pip.get_big_parameter_dimension() == not_a_dimension())
+  if (pip.get_big_parameter_dimension() == not_a_dimension()) {
     s << "\nNo big-parameter set.\n";
-  else
+  }
+  else {
     s << "\nBig-parameter: " << Variable(pip.get_big_parameter_dimension());
+  }
   s << "\n";
   return s;
 }
@@ -55,15 +58,16 @@ PPL::PIP_Problem::PIP_Problem(const dimension_type dim)
     initial_context(),
     big_parameter_dimension(not_a_dimension()) {
   // Check for space dimension overflow.
-  if (dim > max_space_dimension())
+  if (dim > max_space_dimension()) {
     throw std::length_error("PPL::PIP_Problem::PIP_Problem(dim):\n"
                             "dim exceeds the maximum allowed "
                             "space dimension.");
+  }
   control_parameters_init();
   PPL_ASSERT(OK());
 }
 
-PPL::PIP_Problem::PIP_Problem(const PIP_Problem &y)
+PPL::PIP_Problem::PIP_Problem(const PIP_Problem& y)
   : external_space_dim(y.external_space_dim),
     internal_space_dim(y.internal_space_dim),
     status(y.status),
@@ -93,8 +97,9 @@ PPL::PIP_Problem::control_parameters_init() {
 
 void
 PPL::PIP_Problem::control_parameters_copy(const PIP_Problem& y) {
-  for (dimension_type i = CONTROL_PARAMETER_NAME_SIZE; i-- > 0; )
+  for (dimension_type i = CONTROL_PARAMETER_NAME_SIZE; i-- > 0; ) {
     control_parameters[i] = y.control_parameters[i];
+  }
 }
 
 PPL::PIP_Problem_Status
@@ -113,14 +118,16 @@ PPL::PIP_Problem::solve() const {
     {
       PIP_Problem& x = const_cast<PIP_Problem&>(*this);
       // Allocate PIP solution tree root, if needed.
-      if (current_solution == 0)
+      if (current_solution == 0) {
         x.current_solution = new PIP_Solution_Node(this);
+      }
 
       // Properly resize context matrix.
       const dimension_type new_num_cols = parameters.size() + 1;
       const dimension_type old_num_cols = initial_context.num_columns();
-      if (old_num_cols < new_num_cols)
+      if (old_num_cols < new_num_cols) {
         x.initial_context.add_zero_columns(new_num_cols - old_num_cols);
+      }
 
       // Computed once for all (to be used inside loop).
       const Variables_Set::const_iterator param_begin = parameters.begin();
@@ -140,8 +147,9 @@ PPL::PIP_Problem::solve() const {
 
         // Constraints having a non-zero variable coefficient
         // should not be inserted in context.
-        if (!c.expression().all_zeroes_except(parameters, 1, c_space_dim + 1))
+        if (!c.expression().all_zeroes_except(parameters, 1, c_space_dim + 1)) {
           continue;
+        }
 
         check_feasible_context = true;
 
@@ -155,12 +163,15 @@ PPL::PIP_Problem::solve() const {
           if (c.inhomogeneous_term() != 0) {
             itr = row.insert(0, c.inhomogeneous_term());
             // Adjust inhomogeneous term if strict.
-            if (c.is_strict_inequality())
+            if (c.is_strict_inequality()) {
               --(*itr);
-          } else {
+            }
+          }
+          else {
             // Adjust inhomogeneous term if strict.
-            if (c.is_strict_inequality())
+            if (c.is_strict_inequality()) {
               itr = row.insert(0, -1);
+            }
           }
           dimension_type i = 1;
 
@@ -174,10 +185,13 @@ PPL::PIP_Problem::solve() const {
             if (*pi < c_space_dim) {
               Coefficient_traits::const_reference coeff_pi
                 = c.coefficient(Variable(*pi));
-              if (coeff_pi != 0)
+              if (coeff_pi != 0) {
                 itr = row.insert(itr, i, coeff_pi);
-            } else
+              }
+            }
+            else {
               break;
+            }
           }
         }
 
@@ -191,9 +205,10 @@ PPL::PIP_Problem::solve() const {
 
           last_row = x.initial_context[x.initial_context.num_rows()-2];
 
-          for (Row::iterator
-               i = last_row.begin(), i_end = last_row.end(); i != i_end; ++i)
+          for (Row::iterator i = last_row.begin(),
+                 i_end = last_row.end(); i != i_end; ++i) {
             neg_assign(*i);
+          }
         }
       }
 
@@ -244,15 +259,17 @@ PPL::PIP_Problem::solve() const {
 
 PPL::PIP_Tree
 PPL::PIP_Problem::solution() const {
-  if (status == PARTIALLY_SATISFIABLE)
+  if (status == PARTIALLY_SATISFIABLE) {
     solve();
+  }
   return current_solution;
 }
 
 PPL::PIP_Tree
 PPL::PIP_Problem::optimizing_solution() const {
-  if (status == PARTIALLY_SATISFIABLE)
+  if (status == PARTIALLY_SATISFIABLE) {
     solve();
+  }
   return current_solution;
 }
 
@@ -266,8 +283,8 @@ PPL::PIP_Problem::OK() const {
   if (external_space_dim < internal_space_dim) {
 #ifndef NDEBUG
       cerr << "The internal space dimension of the PIP_Problem is "
-	   << "greater than its external space dimension."
-	   << endl;
+           << "greater than its external space dimension."
+           << endl;
       ascii_dump(cerr);
 #endif
       return false;
@@ -280,7 +297,7 @@ PPL::PIP_Problem::OK() const {
 #ifndef NDEBUG
       cerr << "The space dimension of the PIP_Problem is smaller than "
            << "the space dimension of one of its constraints."
-	   << endl;
+           << endl;
       ascii_dump(cerr);
 #endif
       return false;
@@ -294,7 +311,7 @@ PPL::PIP_Problem::OK() const {
       && strategy != CUTTING_STRATEGY_ALL) {
 #ifndef NDEBUG
     cerr << "Invalid value for the CUTTING_STRATEGY control parameter."
-	 << endl;
+         << endl;
     ascii_dump(cerr);
 #endif
     return false;
@@ -320,10 +337,12 @@ PPL::PIP_Problem::OK() const {
     return false;
   }
 
-  if (!parameters.OK())
+  if (!parameters.OK()) {
     return false;
-  if (!initial_context.OK())
+  }
+  if (!initial_context.OK()) {
     return false;
+  }
 
   if (current_solution != 0) {
     // Check well formedness of the solution tree.
@@ -358,8 +377,9 @@ PPL::PIP_Problem::ascii_dump(std::ostream& s) const {
   const dimension_type input_cs_size = input_cs.size();
 
   s << "\ninput_cs( " << input_cs_size << " )\n";
-  for (dimension_type i = 0; i < input_cs_size; ++i)
+  for (dimension_type i = 0; i < input_cs_size; ++i) {
     input_cs[i].ascii_dump(s);
+  }
 
   s << "\nfirst_pending_constraint: " <<  first_pending_constraint << "\n";
 
@@ -385,7 +405,7 @@ PPL::PIP_Problem::ascii_dump(std::ostream& s) const {
 
   s << "\ncontrol_parameters\n";
   for (dimension_type i = 0; i < CONTROL_PARAMETER_NAME_SIZE; ++i) {
-    Control_Parameter_Value value = control_parameters[i];
+    const Control_Parameter_Value value = control_parameters[i];
     switch (value) {
     case CUTTING_STRATEGY_FIRST:
       s << "CUTTING_STRATEGY_FIRST";
@@ -411,14 +431,16 @@ PPL::PIP_Problem::ascii_dump(std::ostream& s) const {
   s << "\nbig_parameter_dimension: " << big_parameter_dimension << "\n";
 
   s << "\ncurrent_solution: ";
-  if (current_solution == 0)
+  if (current_solution == 0) {
     s << "BOTTOM\n";
-  else if (const PIP_Decision_Node* dec = current_solution->as_decision()) {
+  }
+  else if (const PIP_Decision_Node* const dec
+             = current_solution->as_decision()) {
     s << "DECISION\n";
     dec->ascii_dump(s);
   }
   else {
-    const PIP_Solution_Node* sol = current_solution->as_solution();
+    const PIP_Solution_Node* const sol = current_solution->as_solution();
     PPL_ASSERT(sol != 0);
     s << "SOLUTION\n";
     sol->ascii_dump(s);
@@ -430,123 +452,159 @@ PPL_OUTPUT_DEFINITIONS(PIP_Problem)
 bool
 PPL::PIP_Problem::ascii_load(std::istream& s) {
   std::string str;
-  if (!(s >> str) || str != "external_space_dim:")
+  if (!(s >> str) || str != "external_space_dim:") {
     return false;
+  }
 
-  if (!(s >> external_space_dim))
+  if (!(s >> external_space_dim)) {
     return false;
+  }
 
-  if (!(s >> str) || str != "internal_space_dim:")
+  if (!(s >> str) || str != "internal_space_dim:") {
     return false;
+  }
 
-  if (!(s >> internal_space_dim))
+  if (!(s >> internal_space_dim)) {
     return false;
+  }
 
-  if (!(s >> str) || str != "input_cs(")
+  if (!(s >> str) || str != "input_cs(") {
     return false;
+  }
 
   dimension_type input_cs_size;
 
-  if (!(s >> input_cs_size))
+  if (!(s >> input_cs_size)) {
     return false;
+  }
 
-  if (!(s >> str) || str != ")")
+  if (!(s >> str) || str != ")") {
     return false;
+  }
 
   Constraint c(Constraint::zero_dim_positivity());
   for (dimension_type i = 0; i < input_cs_size; ++i) {
-    if (!c.ascii_load(s))
+    if (!c.ascii_load(s)) {
       return false;
+    }
     input_cs.push_back(c);
   }
 
-  if (!(s >> str) || str != "first_pending_constraint:")
+  if (!(s >> str) || str != "first_pending_constraint:") {
     return false;
+  }
 
-  if (!(s >> first_pending_constraint))
+  if (!(s >> first_pending_constraint)) {
     return false;
+  }
 
-  if (!(s >> str) || str != "status:")
+  if (!(s >> str) || str != "status:") {
     return false;
+  }
 
-  if (!(s >> str))
+  if (!(s >> str)) {
     return false;
+  }
 
-  if (str == "UNSATISFIABLE")
+  if (str == "UNSATISFIABLE") {
     status = UNSATISFIABLE;
-  else if (str == "OPTIMIZED")
+  }
+  else if (str == "OPTIMIZED") {
     status = OPTIMIZED;
-  else if (str == "PARTIALLY_SATISFIABLE")
+  }
+  else if (str == "PARTIALLY_SATISFIABLE") {
     status = PARTIALLY_SATISFIABLE;
-  else
+  }
+  else {
     return false;
+  }
 
-  if (!(s >> str) || str != "parameters")
+  if (!(s >> str) || str != "parameters") {
     return false;
+  }
 
-  if (!parameters.ascii_load(s))
+  if (!parameters.ascii_load(s)) {
     return false;
+  }
 
-  if (!(s >> str) || str != "initial_context")
+  if (!(s >> str) || str != "initial_context") {
     return false;
+  }
 
-  if (!initial_context.ascii_load(s))
+  if (!initial_context.ascii_load(s)) {
     return false;
+  }
 
-  if (!(s >> str) || str != "control_parameters")
+  if (!(s >> str) || str != "control_parameters") {
     return false;
+  }
 
   for (dimension_type i = 0; i < CONTROL_PARAMETER_NAME_SIZE; ++i) {
-    if (!(s >> str))
+    if (!(s >> str)) {
       return false;
+    }
     Control_Parameter_Value value;
-    if (str == "CUTTING_STRATEGY_FIRST")
+    if (str == "CUTTING_STRATEGY_FIRST") {
       value = CUTTING_STRATEGY_FIRST;
-    else if (str == "CUTTING_STRATEGY_DEEPEST")
+    }
+    else if (str == "CUTTING_STRATEGY_DEEPEST") {
       value = CUTTING_STRATEGY_DEEPEST;
-    else if (str == "CUTTING_STRATEGY_ALL")
+    }
+    else if (str == "CUTTING_STRATEGY_ALL") {
       value = CUTTING_STRATEGY_ALL;
-    else if (str == "PIVOT_ROW_STRATEGY_FIRST")
+    }
+    else if (str == "PIVOT_ROW_STRATEGY_FIRST") {
       value = PIVOT_ROW_STRATEGY_FIRST;
-    else if (str == "PIVOT_ROW_STRATEGY_MAX_COLUMN")
+    }
+    else if (str == "PIVOT_ROW_STRATEGY_MAX_COLUMN") {
       value = PIVOT_ROW_STRATEGY_MAX_COLUMN;
-    else
+    }
+    else {
       return false;
+    }
     control_parameters[i] = value;
   }
 
-  if (!(s >> str) || str != "big_parameter_dimension:")
+  if (!(s >> str) || str != "big_parameter_dimension:") {
     return false;
-  if (!(s >> big_parameter_dimension))
+  }
+  if (!(s >> big_parameter_dimension)) {
     return false;
+  }
 
   // Release current_solution tree (if any).
   delete current_solution;
   current_solution = 0;
   // Load current_solution (if any).
-  if (!(s >> str) || str != "current_solution:")
+  if (!(s >> str) || str != "current_solution:") {
     return false;
-  if (!(s >> str))
+  }
+  if (!(s >> str)) {
     return false;
-  if (str == "BOTTOM")
+  }
+  if (str == "BOTTOM") {
     current_solution = 0;
+  }
   else if (str == "DECISION") {
-    PIP_Decision_Node* dec = new PIP_Decision_Node(0, 0, 0);
+    PIP_Decision_Node* const dec = new PIP_Decision_Node(0, 0, 0);
     current_solution = dec;
-    if (!dec->ascii_load(s))
+    if (!dec->ascii_load(s)) {
       return false;
+    }
     dec->set_owner(this);
   }
   else if (str == "SOLUTION") {
-    PIP_Solution_Node* sol = new PIP_Solution_Node(0);
+    PIP_Solution_Node* const sol = new PIP_Solution_Node(0);
     current_solution = sol;
-    if (!sol->ascii_load(s))
+    if (!sol->ascii_load(s)) {
       return false;
+    }
     sol->set_owner(this);
   }
-  else
+  else {
     // Unknown node kind.
     return false;
+  }
 
   PPL_ASSERT(OK());
   return true;
@@ -575,8 +633,9 @@ PPL::PIP_Problem
                                  const dimension_type m_params) {
   // Adding no space dims at all is a no-op:
   // this avoids invalidating problem status (if it was optimized).
-  if (m_vars == 0 && m_params == 0)
+  if (m_vars == 0 && m_params == 0) {
     return;
+  }
 
   // The space dimension of the resulting PIP problem should not
   // overflow the maximum allowed space dimension.
@@ -586,11 +645,12 @@ PPL::PIP_Problem
     available -= m_vars;
     should_throw = (m_params > available);
   }
-  if (should_throw)
+  if (should_throw) {
     throw std::length_error("PPL::PIP_Problem::"
                             "add_space_dimensions_and_embed(m_v, m_p):\n"
                             "adding m_v+m_p new space dimensions exceeds "
                             "the maximum allowed space dimension.");
+  }
   // First add PIP variables ...
   external_space_dim += m_vars;
   // ... then add PIP parameters.
@@ -599,19 +659,21 @@ PPL::PIP_Problem
     ++external_space_dim;
   }
   // Update problem status.
-  if (status != UNSATISFIABLE)
+  if (status != UNSATISFIABLE) {
     status = PARTIALLY_SATISFIABLE;
+  }
   PPL_ASSERT(OK());
 }
 
 void
 PPL::PIP_Problem
 ::add_to_parameter_space_dimensions(const Variables_Set& p_vars) {
-  if (p_vars.space_dimension() > external_space_dim)
+  if (p_vars.space_dimension() > external_space_dim) {
     throw std::invalid_argument("PPL::PIP_Problem::"
                                 "add_to_parameter_space_dimension(p_vars):\n"
                                 "*this and p_vars are dimension "
                                 "incompatible.");
+  }
   const dimension_type original_size = parameters.size();
   parameters.insert(p_vars.begin(), p_vars.end());
   // Do not allow to turn variables into parameters.
@@ -626,8 +688,9 @@ PPL::PIP_Problem
 
   // If a new parameter was inserted, set the internal status to
   // PARTIALLY_SATISFIABLE.
-  if (parameters.size() != original_size && status != UNSATISFIABLE)
+  if (parameters.size() != original_size && status != UNSATISFIABLE) {
     status = PARTIALLY_SATISFIABLE;
+  }
 }
 
 void
@@ -641,21 +704,24 @@ PPL::PIP_Problem::add_constraint(const Constraint& c) {
   }
   input_cs.push_back(c);
   // Update problem status.
-  if (status != UNSATISFIABLE)
+  if (status != UNSATISFIABLE) {
     status = PARTIALLY_SATISFIABLE;
+  }
 }
 
 void
-PPL::PIP_Problem::add_constraints(const Constraint_System &cs) {
+PPL::PIP_Problem::add_constraints(const Constraint_System& cs) {
   for (Constraint_System::const_iterator ci = cs.begin(),
-         ci_end = cs.end(); ci != ci_end; ++ci)
+         ci_end = cs.end(); ci != ci_end; ++ci) {
     add_constraint(*ci);
+  }
 }
 
 bool
 PPL::PIP_Problem::is_satisfiable() const {
-  if (status == PARTIALLY_SATISFIABLE)
+  if (status == PARTIALLY_SATISFIABLE) {
     solve();
+  }
   return status == OPTIMIZED;
 }
 
@@ -682,15 +748,17 @@ PPL::PIP_Problem::set_control_parameter(Control_Parameter_Value value) {
 
 void
 PPL::PIP_Problem::set_big_parameter_dimension(dimension_type big_dim) {
-  if (parameters.count(big_dim) == 0)
+  if (parameters.count(big_dim) == 0) {
     throw std::invalid_argument("PPL::PIP_Problem::"
                                 "set_big_parameter_dimension(big_dim):\n"
                                 "dimension 'big_dim' is not a parameter.");
-  if (big_dim < internal_space_dim)
+  }
+  if (big_dim < internal_space_dim) {
     throw std::invalid_argument("PPL::PIP_Problem::"
                                 "set_big_parameter_dimension(big_dim):\n"
                                 "only newly-added parameters can be"
                                 "converted into the big parameter.");
+  }
   big_parameter_dimension = big_dim;
 }
 
@@ -698,13 +766,15 @@ PPL::memory_size_type
 PPL::PIP_Problem::external_memory_in_bytes() const {
   memory_size_type n = initial_context.external_memory_in_bytes();
   // Adding the external memory for `current_solution'.
-  if (current_solution != 0)
+  if (current_solution != 0) {
     n += current_solution->total_memory_in_bytes();
+  }
   // Adding the external memory for `input_cs'.
   n += input_cs.capacity() * sizeof(Constraint);
   for (const_iterator i = input_cs.begin(),
-       i_end = input_cs.end(); i != i_end; ++i)
+         i_end = input_cs.end(); i != i_end; ++i) {
     n += (i->external_memory_in_bytes());
+  }
   // FIXME: Adding the external memory for `parameters'.
   n += parameters.size() * sizeof(dimension_type);
 
@@ -735,4 +805,3 @@ PPL::PIP_Problem::print_solution(std::ostream& s, int indent) const {
                            "the PIP problem has not been solved.");
   }
 }
-
