@@ -1,6 +1,6 @@
 /* Sparse_Row class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2016 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -31,18 +31,20 @@ namespace {
 
 class Sparse_Row_from_Dense_Row_helper_iterator {
 public:
-  Sparse_Row_from_Dense_Row_helper_iterator(const PPL::Dense_Row& row1,
+  Sparse_Row_from_Dense_Row_helper_iterator(const PPL::Dense_Row& r,
                                             PPL::dimension_type sz)
-    : row(row1), sz(sz), i(0) {
-    if (row.size() != 0 && row[0] == 0)
+    : row(r), sz(sz), idx(0) {
+    if (row.size() != 0 && row[0] == 0) {
       ++(*this);
+    }
   }
 
   Sparse_Row_from_Dense_Row_helper_iterator& operator++() {
-    PPL_ASSERT(i < sz);
-    ++i;
-    while (i < sz && row[i] == 0)
-      ++i;
+    PPL_ASSERT(idx < sz);
+    ++idx;
+    while (idx < sz && row[idx] == 0) {
+      ++idx;
+    }
     return *this;
   }
 
@@ -54,20 +56,20 @@ public:
 
   PPL::Coefficient_traits::const_reference
   operator*() const {
-    PPL_ASSERT(i < sz);
-    return row[i];
+    PPL_ASSERT(idx < sz);
+    return row[idx];
   }
 
   PPL::dimension_type
   index() const {
-    PPL_ASSERT(i < sz);
-    return i;
+    PPL_ASSERT(idx < sz);
+    return idx;
   }
 
   bool
   operator==(const Sparse_Row_from_Dense_Row_helper_iterator& itr) const {
     PPL_ASSERT(&row == &(itr.row));
-    return i == itr.i;
+    return idx == itr.idx;
   }
 
   bool
@@ -78,7 +80,7 @@ public:
 private:
   const PPL::Dense_Row& row;
   PPL::dimension_type sz;
-  PPL::dimension_type i;
+  PPL::dimension_type idx;
 };
 
 // Returns the number of nonzero elements in row.
@@ -86,9 +88,11 @@ PPL::dimension_type
 Sparse_Row_from_Dense_Row_helper_function(const PPL::Dense_Row& row,
                                           PPL::dimension_type sz) {
   PPL::dimension_type count = 0;
-  for (PPL::dimension_type i = sz; i-- > 0; )
-    if (row[i] != 0)
+  for (PPL::dimension_type i = sz; i-- > 0; ) {
+    if (row[i] != 0) {
       ++count;
+    }
+  }
   return count;
 }
 
@@ -124,17 +128,19 @@ PPL::Sparse_Row::swap_coefficients(dimension_type i, dimension_type j) {
   PPL_ASSERT(i < size_);
   PPL_ASSERT(j < size_);
 
-  if (tree.empty())
+  if (tree.empty()) {
     return;
+  }
 
   using std::swap;
 
   iterator itr_i = tree.bisect(i);
   iterator itr_j = tree.bisect(j);
-  if (itr_i.index() == i)
-    if (itr_j.index() == j)
+  if (itr_i.index() == i) {
+    if (itr_j.index() == j) {
       // Both elements are in the tree.
       swap(*itr_i, *itr_j);
+    }
     else {
       // i is in the tree, j is not.
       PPL_DIRTY_TEMP_COEFFICIENT(tmp);
@@ -144,7 +150,8 @@ PPL::Sparse_Row::swap_coefficients(dimension_type i, dimension_type j) {
       itr_j = tree.insert(j);
       swap(*itr_j, tmp);
     }
-  else
+  }
+  else {
     if (itr_j.index() == j) {
       // j is in the tree, i is not.
       PPL_DIRTY_TEMP_COEFFICIENT(tmp);
@@ -157,20 +164,24 @@ PPL::Sparse_Row::swap_coefficients(dimension_type i, dimension_type j) {
     else {
       // Do nothing, elements are both non-stored zeroes.
     }
+  }
 }
 
 PPL::Sparse_Row::iterator
 PPL::Sparse_Row::reset(iterator first, iterator last) {
-  if (first == last)
+  if (first == last) {
     return first;
+  }
+
   PPL_ASSERT(last != end());
   --last;
   const dimension_type j = last.index();
   PPL_ASSERT(first.index() <= j);
   // We can't just compare first and last at each iteration, because last will
   // be invalidated by the first erase.
-  while (first.index() < j)
+  while (first.index() < j) {
     first = reset(first);
+  }
 
   first = reset(first);
 
@@ -188,8 +199,9 @@ PPL::Sparse_Row::reset_after(dimension_type i) {
   // reset().
   const iterator& itr_end = end();
 
-  while (itr != itr_end)
+  while (itr != itr_end) {
     itr = reset(itr);
+  }
 
   PPL_ASSERT(OK());
 }
@@ -204,8 +216,9 @@ PPL::Sparse_Row::normalize() {
     Coefficient_traits::const_reference x_i = *i;
     if (const int x_i_sign = sgn(x_i)) {
       gcd = x_i;
-      if (x_i_sign < 0)
+      if (x_i_sign < 0) {
         neg_assign(gcd);
+      }
       goto compute_gcd;
     }
   }
@@ -213,8 +226,9 @@ PPL::Sparse_Row::normalize() {
   return;
 
  compute_gcd:
-  if (gcd == 1)
+  if (gcd == 1) {
     return;
+  }
   for (++i; i != i_end; ++i) {
     Coefficient_traits::const_reference x_i = *i;
     if (x_i != 0) {
@@ -230,8 +244,9 @@ PPL::Sparse_Row::normalize() {
       // integers we cannot make any assumption, so here we draw.
       // Overall, we win.
       gcd_assign(gcd, x_i, gcd);
-      if (gcd == 1)
+      if (gcd == 1) {
         return;
+      }
     }
   }
   // Divide the coefficients by the GCD.
@@ -260,10 +275,12 @@ public:
   }
 
   void operator++() {
-    if (from_i)
+    if (from_i) {
       ++i;
-    if (from_j)
+    }
+    if (from_j) {
       ++j;
+    }
     update_current_data();
   }
 
@@ -363,8 +380,9 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
     for (const_iterator j = y.begin(), j_end = y.end(); j != j_end; ++j) {
       i = insert(i, j.index());
       add_mul_assign(*i, *j, coeff2);
-      if (*i == 0)
+      if (*i == 0) {
         i = reset(i);
+      }
     }
     return;
   }
@@ -382,25 +400,29 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
         if (i.index() == j.index()) {
           ++i;
           ++j;
-          if (i == i_end)
+          if (i == i_end) {
             break;
+          }
         }
-        else
+        else {
           if (i.index() < j.index()) {
             i = lower_bound(i, j.index());
-            if (i == i_end)
+            if (i == i_end) {
               break;
+            }
           }
           else {
             PPL_ASSERT(i.index() > j.index());
             ++counter;
             ++j;
           }
+        }
       }
     }
     PPL_ASSERT(i == i_end || j == j_end);
-    for ( ; j != j_end; ++j)
+    for ( ; j != j_end; ++j) {
       ++counter;
+    }
   }
   // This condition is arbitrary. Changing it affects performance but not
   // correctness. The values have been tuned using some ppl_lpsol benchmarks
@@ -418,13 +440,15 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
       if (i.index() == j.index()) {
         (*i) *= coeff1;
         add_mul_assign(*i, *j, coeff2);
-        if (*i == 0)
+        if (*i == 0) {
           i = reset(i);
-        else
+        }
+        else {
           ++i;
+        }
         ++j;
       }
-      else
+      else {
         if (i.index() < j.index()) {
           (*i) *= coeff1;
           ++i;
@@ -436,10 +460,12 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
           ++i;
           ++j;
         }
+      }
     }
     PPL_ASSERT(i == i_end || j == j_end);
-    for ( ; i != i_end; ++i)
+    for ( ; i != i_end; ++i) {
       (*i) *= coeff1;
+    }
     for ( ; j != j_end; ++j) {
       i = insert(i, j.index(), *j);
       (*i) *= coeff2;
@@ -466,8 +492,9 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
         i = reset(i);
         PPL_ASSERT(find(old_index) == end());
       }
-      else
+      else {
         ++i;
+      }
     }
   }
 }
@@ -489,8 +516,9 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
              j_end = y.lower_bound(end); j != j_end; ++j) {
         i = insert(i, j.index());
         *i += *j;
-        if (*i == 0)
+        if (*i == 0) {
           i = reset(i);
+        }
       }
       return;
     }
@@ -501,8 +529,9 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
              j_end = y.lower_bound(end); j != j_end; ++j) {
         i = insert(i, j.index());
         *i -= *j;
-        if (*i == 0)
+        if (*i == 0) {
           i = reset(i);
+        }
       }
       return;
     }
@@ -512,8 +541,9 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
            j_end = y.lower_bound(end); j != j_end; ++j) {
       i = insert(i, j.index());
       add_mul_assign(*i, *j, coeff2);
-      if (*i == 0)
+      if (*i == 0) {
         i = reset(i);
+      }
     }
     return;
   }
@@ -531,13 +561,15 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
       if (i.index() == j.index()) {
         (*i) *= coeff1;
         *i += *j;
-        if (*i == 0)
+        if (*i == 0) {
           i = reset(i);
-        else
+        }
+        else {
           ++i;
+        }
         ++j;
       }
-      else
+      else {
         if (i.index() < j.index()) {
           (*i) *= coeff1;
           ++i;
@@ -548,12 +580,15 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
           ++i;
           ++j;
         }
+      }
     }
     PPL_ASSERT(i == i_end || j == j_end);
-    for ( ; i != i_end && i.index() < end; ++i)
+    for ( ; i != i_end && i.index() < end; ++i) {
       (*i) *= coeff1;
-    for ( ; j != j_end; ++j)
+    }
+    for ( ; j != j_end; ++j) {
       i = insert(i, j.index(), *j);
+    }
     return;
   }
 
@@ -570,13 +605,15 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
       if (i.index() == j.index()) {
         (*i) *= coeff1;
         *i -= *j;
-        if (*i == 0)
+        if (*i == 0) {
           i = reset(i);
-        else
+        }
+        else {
           ++i;
+        }
         ++j;
       }
-      else
+      else {
         if (i.index() < j.index()) {
           (*i) *= coeff1;
           ++i;
@@ -588,10 +625,12 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
           ++i;
           ++j;
         }
+      }
     }
     PPL_ASSERT(i == i_end || j == j_end);
-    for ( ; i != i_end && i.index() < end; ++i)
+    for ( ; i != i_end && i.index() < end; ++i) {
       (*i) *= coeff1;
+    }
     for ( ; j != j_end; ++j) {
       i = insert(i, j.index(), *j);
       neg_assign(*i);
@@ -610,13 +649,15 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
     if (i.index() == j.index()) {
       (*i) *= coeff1;
       add_mul_assign(*i, *j, coeff2);
-      if (*i == 0)
+      if (*i == 0) {
         i = reset(i);
-      else
+      }
+      else {
         ++i;
+      }
       ++j;
     }
-    else
+    else {
       if (i.index() < j.index()) {
         (*i) *= coeff1;
         ++i;
@@ -628,10 +669,12 @@ PPL::Sparse_Row::linear_combine(const Sparse_Row& y,
         ++i;
         ++j;
       }
+    }
   }
   PPL_ASSERT(i == i_end || j == j_end);
-  for ( ; i != i_end && i.index() < end; ++i)
+  for ( ; i != i_end && i.index() < end; ++i) {
     (*i) *= coeff1;
+  }
   for ( ; j != j_end; ++j) {
     i = insert(i, j.index(), *j);
     (*i) *= coeff2;
@@ -642,11 +685,13 @@ void
 PPL::Sparse_Row::ascii_dump(std::ostream& s) const {
   s << "size " << size_ << ' ';
   dimension_type n_elements = 0;
-  for (const_iterator i = begin(), i_end = end(); i != i_end; ++i)
+  for (const_iterator i = begin(), i_end = end(); i != i_end; ++i) {
     ++n_elements;
+  }
   s << "elements " << n_elements << ' ';
-  for (const_iterator i = begin(), i_end = end(); i != i_end; ++i)
+  for (const_iterator i = begin(), i_end = end(); i != i_end; ++i) {
     s << "[ " << i.index() << " ]= " << *i << ' ';
+  }
   s << "\n";
 }
 
@@ -655,30 +700,38 @@ PPL_OUTPUT_DEFINITIONS_ASCII_ONLY(Sparse_Row)
 bool
 PPL::Sparse_Row::ascii_load(std::istream& s) {
   std::string str;
-  if (!(s >> str) || str != "size")
+  if (!(s >> str) || str != "size") {
     return false;
-  if (!(s >> size_))
+  }
+  if (!(s >> size_)) {
     return false;
+  }
   clear();
 
-  if (!(s >> str) || str != "elements")
+  if (!(s >> str) || str != "elements") {
     return false;
+  }
 
   dimension_type n_elements;
-  if (!(s >> n_elements))
+  if (!(s >> n_elements)) {
     return false;
+  }
 
   PPL_DIRTY_TEMP_COEFFICIENT(current_data);
   for (dimension_type i = 0; i < n_elements; ++i) {
     dimension_type current_key;
-    if (!(s >> str) || str != "[")
+    if (!(s >> str) || str != "[") {
       return false;
-    if (!(s >> current_key))
+    }
+    if (!(s >> current_key)) {
       return false;
-    if (!(s >> str) || str != "]=")
+    }
+    if (!(s >> str) || str != "]=") {
       return false;
-    if (!(s >> current_data))
+    }
+    if (!(s >> current_data)) {
       return false;
+    }
     tree.insert(current_key, current_data);
   }
   PPL_ASSERT(OK());
@@ -687,8 +740,9 @@ PPL::Sparse_Row::ascii_load(std::istream& s) {
 
 bool
 PPL::Sparse_Row::OK() const {
-  if (begin() == end())
+  if (begin() == end()) {
     return true;
+  }
   const_iterator last = end();
   --last;
   return (last.index() < size_);
@@ -702,39 +756,47 @@ PPL::Sparse_Row::OK(dimension_type /* capacity */) const {
 /*! \relates Parma_Polyhedra_Library::Sparse_Row */
 bool
 PPL::operator==(const Sparse_Row& x, const Sparse_Row& y) {
-  if (x.size() != y.size())
+  if (x.size() != y.size()) {
     return false;
+  }
   Sparse_Row::const_iterator i = x.begin();
   Sparse_Row::const_iterator i_end = x.end();
   Sparse_Row::const_iterator j = y.begin();
   Sparse_Row::const_iterator j_end = y.end();
   while (i != i_end && j != j_end) {
     if (i.index() == j.index()) {
-      if (*i != *j)
+      if (*i != *j) {
         return false;
+      }
       ++i;
       ++j;
     }
     else {
       if (i.index() < j.index()) {
-        if (*i != 0)
+        if (*i != 0) {
           return false;
+        }
         ++i;
       }
       else {
         PPL_ASSERT(i.index() > j.index());
-        if (*j != 0)
+        if (*j != 0) {
           return false;
+        }
         ++j;
       }
     }
   }
-  for ( ; i != i_end; ++i)
-    if (*i != 0)
+  for ( ; i != i_end; ++i) {
+    if (*i != 0) {
       return false;
-  for ( ; j != j_end; ++j)
-    if (*j != 0)
+    }
+  }
+  for ( ; j != j_end; ++j) {
+    if (*j != 0) {
       return false;
+    }
+  }
   return true;
 }
 
@@ -746,18 +808,21 @@ PPL::operator!=(const Sparse_Row& x, const Sparse_Row& y) {
 
 bool
 PPL::operator==(const Dense_Row& x, const Sparse_Row& y) {
-  if (x.size() != y.size())
+  if (x.size() != y.size()) {
     return false;
+  }
   Sparse_Row::const_iterator itr = y.end();
   for (dimension_type i = 0; i < x.size(); ++i) {
     itr = y.lower_bound(itr, i);
     if (itr != y.end() && itr.index() == i) {
-      if (x[i] != *itr)
+      if (x[i] != *itr) {
         return false;
+      }
     }
     else {
-      if (x[i] != 0)
+      if (x[i] != 0) {
         return false;
+      }
     }
   }
   return true;
@@ -791,8 +856,9 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
   for (dimension_type i = 0; i < y.size(); ++i) {
     itr = x.lower_bound(itr, i);
     if (itr == x.end() || itr.index() != i) {
-      if (y[i] == 0)
+      if (y[i] == 0) {
         continue;
+      }
       itr = x.insert(itr, i, y[i]);
       (*itr) *= coeff2;
       PPL_ASSERT((*itr) != 0);
@@ -801,8 +867,9 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
       PPL_ASSERT(itr.index() == i);
       (*itr) *= coeff1;
       add_mul_assign(*itr, y[i], coeff2);
-      if (*itr == 0)
+      if (*itr == 0) {
         itr = x.reset(itr);
+      }
     }
   }
 }
@@ -824,20 +891,23 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
     if (coeff2 == 1) {
       for (dimension_type i = start; i < end; ++i) {
         PPL_ASSERT(itr == x.end() || itr.index() + 1 >= i);
-        if (itr != x.end() && itr.index() < i)
+        if (itr != x.end() && itr.index() < i) {
           ++itr;
+        }
         PPL_ASSERT(itr == x.end() || itr.index() >= i);
         if (itr == x.end() || itr.index() != i) {
-          if (y[i] == 0)
+          if (y[i] == 0) {
             continue;
+          }
           itr = x.insert(itr, i, y[i]);
           PPL_ASSERT((*itr) != 0);
         }
         else {
           PPL_ASSERT(itr.index() == i);
           (*itr) += y[i];
-          if (*itr == 0)
+          if (*itr == 0) {
             itr = x.reset(itr);
+          }
         }
       }
       return;
@@ -845,12 +915,14 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
     if (coeff2 == -1) {
       for (dimension_type i = start; i < end; ++i) {
         PPL_ASSERT(itr == x.end() || itr.index() + 1 >= i);
-        if (itr != x.end() && itr.index() < i)
+        if (itr != x.end() && itr.index() < i) {
           ++itr;
+        }
         PPL_ASSERT(itr == x.end() || itr.index() >= i);
         if (itr == x.end() || itr.index() != i) {
-          if (y[i] == 0)
+          if (y[i] == 0) {
             continue;
+          }
           itr = x.insert(itr, i, y[i]);
           neg_assign(*itr);
           PPL_ASSERT((*itr) != 0);
@@ -858,20 +930,23 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
         else {
           PPL_ASSERT(itr.index() == i);
           (*itr) -= y[i];
-          if (*itr == 0)
+          if (*itr == 0) {
             itr = x.reset(itr);
+          }
         }
       }
       return;
     }
     for (dimension_type i = start; i < end; ++i) {
       PPL_ASSERT(itr == x.end() || itr.index() + 1 >= i);
-      if (itr != x.end() && itr.index() < i)
+      if (itr != x.end() && itr.index() < i) {
         ++itr;
+      }
       PPL_ASSERT(itr == x.end() || itr.index() >= i);
       if (itr == x.end() || itr.index() != i) {
-        if (y[i] == 0)
+        if (y[i] == 0) {
           continue;
+        }
         itr = x.insert(itr, i, y[i]);
         (*itr) *= coeff2;
         PPL_ASSERT((*itr) != 0);
@@ -879,8 +954,9 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
       else {
         PPL_ASSERT(itr.index() == i);
         add_mul_assign(*itr, y[i], coeff2);
-        if (*itr == 0)
+        if (*itr == 0) {
           itr = x.reset(itr);
+        }
       }
     }
     return;
@@ -889,12 +965,14 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
   if (coeff2 == 1) {
     for (dimension_type i = start; i < end; ++i) {
       PPL_ASSERT(itr == x.end() || itr.index() + 1 >= i);
-      if (itr != x.end() && itr.index() < i)
+      if (itr != x.end() && itr.index() < i) {
         ++itr;
+      }
       PPL_ASSERT(itr == x.end() || itr.index() >= i);
       if (itr == x.end() || itr.index() != i) {
-        if (y[i] == 0)
+        if (y[i] == 0) {
           continue;
+        }
         itr = x.insert(itr, i, y[i]);
         PPL_ASSERT((*itr) != 0);
       }
@@ -902,8 +980,9 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
         PPL_ASSERT(itr.index() == i);
         (*itr) *= coeff1;
         (*itr) += y[i];
-        if (*itr == 0)
+        if (*itr == 0) {
           itr = x.reset(itr);
+        }
       }
     }
     return;
@@ -911,12 +990,14 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
   if (coeff2 == -1) {
     for (dimension_type i = start; i < end; ++i) {
       PPL_ASSERT(itr == x.end() || itr.index() + 1 >= i);
-      if (itr != x.end() && itr.index() < i)
+      if (itr != x.end() && itr.index() < i) {
         ++itr;
+      }
       PPL_ASSERT(itr == x.end() || itr.index() >= i);
       if (itr == x.end() || itr.index() != i) {
-        if (y[i] == 0)
+        if (y[i] == 0) {
           continue;
+        }
         itr = x.insert(itr, i, y[i]);
         neg_assign(*itr);
         PPL_ASSERT((*itr) != 0);
@@ -925,8 +1006,9 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
         PPL_ASSERT(itr.index() == i);
         (*itr) *= coeff1;
         (*itr) -= y[i];
-        if (*itr == 0)
+        if (*itr == 0) {
           itr = x.reset(itr);
+        }
       }
     }
     return;
@@ -934,12 +1016,14 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
 
   for (dimension_type i = start; i < end; ++i) {
     PPL_ASSERT(itr == x.end() || itr.index() + 1 >= i);
-    if (itr != x.end() && itr.index() < i)
+    if (itr != x.end() && itr.index() < i) {
       ++itr;
+    }
     PPL_ASSERT(itr == x.end() || itr.index() >= i);
     if (itr == x.end() || itr.index() != i) {
-      if (y[i] == 0)
+      if (y[i] == 0) {
         continue;
+      }
       itr = x.insert(itr, i, y[i]);
       (*itr) *= coeff2;
       PPL_ASSERT((*itr) != 0);
@@ -948,8 +1032,9 @@ PPL::linear_combine(Sparse_Row& x, const Dense_Row& y,
       PPL_ASSERT(itr.index() == i);
       (*itr) *= coeff1;
       add_mul_assign(*itr, y[i], coeff2);
-      if (*itr == 0)
+      if (*itr == 0) {
         itr = x.reset(itr);
+      }
     }
   }
 }
@@ -961,8 +1046,9 @@ PPL::linear_combine(Dense_Row& x, const Sparse_Row& y,
   PPL_ASSERT(x.size() >= y.size());
   if (coeff1 == 1) {
     for (Sparse_Row::const_iterator i = y.begin(),
-           i_end = y.end(); i != i_end; ++i)
+           i_end = y.end(); i != i_end; ++i) {
       add_mul_assign(x[i.index()], *i, coeff2);
+    }
     return;
   }
 
@@ -973,8 +1059,9 @@ PPL::linear_combine(Dense_Row& x, const Sparse_Row& y,
 
     itr = y.lower_bound(itr, i);
 
-    if (itr == y.end() || itr.index() != i)
+    if (itr == y.end() || itr.index() != i) {
       continue;
+    }
 
     add_mul_assign(x[i], *itr, coeff2);
   }
@@ -994,17 +1081,20 @@ PPL::linear_combine(Dense_Row& x, const Sparse_Row& y,
   if (coeff1 == 1) {
     Sparse_Row::const_iterator itr_end = y.lower_bound(end);
     if (coeff2 == 1) {
-      for ( ; itr != itr_end; ++itr)
+      for ( ; itr != itr_end; ++itr) {
         x[itr.index()] += *itr;
+      }
       return;
     }
     if (coeff2 == -1) {
-      for ( ; itr != itr_end; ++itr)
+      for ( ; itr != itr_end; ++itr) {
         x[itr.index()] -= *itr;
+      }
       return;
     }
-    for ( ; itr != itr_end; ++itr)
+    for ( ; itr != itr_end; ++itr) {
       add_mul_assign(x[itr.index()], *itr, coeff2);
+    }
     return;
   }
 
@@ -1013,12 +1103,14 @@ PPL::linear_combine(Dense_Row& x, const Sparse_Row& y,
       x[i] *= coeff1;
 
       PPL_ASSERT(itr == y.end() || itr.index() + 1 >= i);
-      if (itr != y.end() && itr.index() < i)
+      if (itr != y.end() && itr.index() < i) {
         ++itr;
+      }
       PPL_ASSERT(itr == y.end() || itr.index() >= i);
 
-      if (itr == y.end() || itr.index() != i)
+      if (itr == y.end() || itr.index() != i) {
         continue;
+      }
 
       x[i] += *itr;
     }
@@ -1029,12 +1121,14 @@ PPL::linear_combine(Dense_Row& x, const Sparse_Row& y,
       x[i] *= coeff1;
 
       PPL_ASSERT(itr == y.end() || itr.index() + 1 >= i);
-      if (itr != y.end() && itr.index() < i)
+      if (itr != y.end() && itr.index() < i) {
         ++itr;
+      }
       PPL_ASSERT(itr == y.end() || itr.index() >= i);
 
-      if (itr == y.end() || itr.index() != i)
+      if (itr == y.end() || itr.index() != i) {
         continue;
+      }
 
       x[i] -= *itr;
     }
@@ -1045,12 +1139,14 @@ PPL::linear_combine(Dense_Row& x, const Sparse_Row& y,
     x[i] *= coeff1;
 
     PPL_ASSERT(itr == y.end() || itr.index() + 1 >= i);
-    if (itr != y.end() && itr.index() < i)
+    if (itr != y.end() && itr.index() < i) {
       ++itr;
+    }
     PPL_ASSERT(itr == y.end() || itr.index() >= i);
 
-    if (itr == y.end() || itr.index() != i)
+    if (itr == y.end() || itr.index() != i) {
       continue;
+    }
 
     add_mul_assign(x[i], *itr, coeff2);
   }
@@ -1075,8 +1171,10 @@ void
 PPL::swap(Sparse_Row& x, Dense_Row& y) {
   Dense_Row new_dense(x.size(), x.size());
 
-  for (Sparse_Row::iterator i = x.begin(), i_end = x.end(); i != i_end; ++i)
+  for (Sparse_Row::iterator i = x.begin(), i_end = x.end();
+       i != i_end; ++i) {
     swap(new_dense[i.index()], *i);
+  }
 
   // NOTE: This copies the coefficients, but it could steal them.
   // Implementing a stealing-based algorithm takes a lot of time and it's
