@@ -1,6 +1,6 @@
 /* Variables_Set class implementation (non-inline functions).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2016 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -29,15 +29,19 @@ namespace PPL = Parma_Polyhedra_Library;
 
 PPL::Variables_Set::Variables_Set(const Variable v, const Variable w)
   : Base() {
-  for (dimension_type d = v.id(), last = w.id(); d <= last; ++d)
+  for (dimension_type d = v.id(), last = w.id(); d <= last; ++d) {
     insert(d);
+  }
 }
 
 bool
 PPL::Variables_Set::OK() const {
-  for (const_iterator i = begin(), set_end = end(); i != set_end; ++i)
-    if (!Variable(*i).OK())
+  for (const_iterator i = begin(), set_end = end();
+       i != set_end; ++i) {
+    if (!Variable(*i).OK()) {
       return false;
+    }
+  }
   return true;
 }
 
@@ -49,8 +53,9 @@ PPL::IO_Operators::operator<<(std::ostream& s, const Variables_Set& vs) {
          vs_end = vs.end(); i != vs_end; ) {
     s << ' ' << Variable(*i);
     ++i;
-    if (i != vs_end)
+    if (i != vs_end) {
       s << ',';
+    }
   }
   s << " }";
   return s;
@@ -61,8 +66,9 @@ PPL::Variables_Set::ascii_dump(std::ostream& s) const {
   const dimension_type variables_set_size = size();
   s << "\nvariables( " << variables_set_size << " )\n";
   for (Variables_Set::const_iterator i = begin(),
-         i_end = end(); i != i_end; ++i)
+         i_end = end(); i != i_end; ++i) {
     s << *i << " ";
+  }
 }
 
 PPL_OUTPUT_DEFINITIONS(Variables_Set)
@@ -71,21 +77,25 @@ bool
 PPL::Variables_Set::ascii_load(std::istream& s) {
   clear();
   std::string str;
-  if (!(s >> str) || str != "variables(")
+  if (!(s >> str) || str != "variables(") {
     return false;
+  }
 
   dimension_type size;
 
-  if (!(s >> size))
+  if (!(s >> size)) {
     return false;
+  }
 
-  if (!(s >> str) || str != ")")
+  if (!(s >> str) || str != ")") {
     return false;
+  }
 
   for (dimension_type i = 0; i < size; ++i) {
     dimension_type variable_value;
-    if (!(s >> variable_value))
+    if (!(s >> variable_value)) {
       return false;
+    }
     insert(variable_value);
   }
   return true;
