@@ -1,6 +1,6 @@
 /* Test the Sparse_Matrix class.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2013 BUGSENG srl (http://bugseng.com)
+   Copyright (C) 2010-2016 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -598,6 +598,13 @@ test09() {
   return true;
 }
 
+bool
+test10() {
+  Sparse_Row sparse(2);
+  Dense_Row dense(sparse, 8, 8);
+  return true;
+}
+
 } // namespace
 
 BEGIN_MAIN
@@ -610,6 +617,7 @@ BEGIN_MAIN
   DO_TEST(test07);
   DO_TEST(test08);
   DO_TEST(test09);
+  DO_TEST(test10);
 END_MAIN
 
 #else // !PPL_USE_SPARSE_MATRIX
